(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    250301,       6484]*)
(*NotebookOutlinePosition[    251319,       6518]*)
(*  CellTagsIndexPosition[    251275,       6514]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computing the Field Perturbation induced by a Shim", "Title"],

Cell[TextData[{
  "P. Elleaume (elleaume@esrf.fr)\nOctober 23  2000, Version 1.0\nThis \
notebook has been developed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0 on a PowerMac. It should execute on other platforms with any version \
of ",
  StyleBox["Mathematica higher than 3. ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell["To Read before Starting ", "Section"],

Cell["\<\
- This notebook is intended to show how to  simulate the effect of \
a shim (small flat piece of iron) placed at the surface of an undulator \
magnet array. The shim and field integral signatures of the shim are computed \
and plotted. A magnet array is built which corresponds to a single jaw pure \
permanent magnet undulator .
- Note that in this example, a permeability of 1 has been assumed for the \
permanent magnets. Taking into account of the real permeability  could be \
easily done by segmenting the magnets and applying a suitable magnetic \
material. If the permeability of the magnets is close to 1, it would result \
in a small correction to the signature of the shims at the cost of more CPU \
time. 
- Starting from this example, one could treat the more difficult case of \
shims placed  at the surface of an hybrid type undulator. Note that in such a \
case, the field signature of the shim  is not equal to the field produced by \
the magnetization of the shim itself, because the presence of the shim also \
modifies the magnetization in the surrounding parts of the iron poles. \
Nevertheless the shim signature could be computed by substracting the field \
of the hybrid structure alone from the field produced by the hybrid structure \
+ shim. 
- Another case of interest is the computation of the field signature induced \
by a block displacement. In the most general case of a hybrid undulator, this \
would need to build two identical structures except for a single displacement \
of a magnet or pole and to compute the field difference. Note that in the \
particular case of a pure permanent magnet array with zero permeability, it \
can be computed in a much easier way by computing the field of two magnets \
with opposite magnetization which corresponds to the algebraic difference  of \
the magnetization  before and after the magnet  displacement. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["How to Use this Notebook", "Section"],

Cell["\<\
1 - Execute the section \"Initialization\"
2 - Edit the parameters and execute the section \"Build the Geometry\"
3  -Execute the cells in the section \"Display the Geometry\" to check the \
size and position of the shim (in red) at the surface of the block (in blue). \

4-  Execute the cells in the section \"Plot the signature of the Shim\" to \
obtain a  plot of the field and field integral produced by the shim .\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Radia`;\)\), "\[IndentingNewLine]", 
    \(\(<< Graphics`MultipleListPlot`;\)\), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Plot, PlotRange \[Rule] All, 
        Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, PlotRange \[Rule] All, Frame \[Rule] True, 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[MultipleListPlot, PlotRange \[Rule] All, 
        Frame \[Rule] True, PlotJoined \[Rule] True];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(geom[] := 
        Module[{}, \[IndentingNewLine]magnets = 
            radObjCnt[{}]; \[IndentingNewLine]y = \(-per\)*3/
                4; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, br, 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, 0, 
                br}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, \(-br\), 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, 
                0, \(-br\)}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, br, 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, 0, 
                br}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]radObjDrwAtr[
            magnets, {0, 0.5, 1}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, \(-br\), 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]\[IndentingNewLine] (*___  ___  \
___  ___\ Generate\ the\ shim\ ___  ___  ___  ___  ___  ___\ \
*) \[IndentingNewLine]\[IndentingNewLine]shim = 
            radObjRecMag[{px, ps, lsz/2 + dz}, {lsx, lss, 
                lsz}]; \[IndentingNewLine]radObjDivMag[shim, 
            seg]; \[IndentingNewLine]radObjDrwAtr[
            shim, {1, 0, 0.5}]; \[IndentingNewLine]radMatApl[shim, 
            RadMatSteel37[]]; \[IndentingNewLine]all = 
            radObjCnt[{shim, magnets}]; \[IndentingNewLine]{all, shim, 
            magnets}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Builg the Geometry ", "Section"],

Cell["\<\
Build a magnet array with a single shim placed at the surface. \
Solve for the magnetization in the shim.  The user is responsible to check \
that the signature of the shim (see below) is unchanged with respec to a \
further subdivision (defined by  seg). \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  ___  ___\ Magnet\ Array\ \ ___  ___  ___  ___*) \
\[IndentingNewLine]\[IndentingNewLine]\(per = 
        35;\)\ \ \ \ \ \ \ \  (*\ \ Period\ \ of\ the\ magnetic\ assembly\ *) \
\), "\[IndentingNewLine]", 
    \(\(lx = 50;\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ size\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(lz = per/2;\)\ \  (*\ 
      Vertical\ size\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(ls = per/4;\)\ \  (*\ 
      Longitudinal\ size\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \ \ \ \ \ \  (*\ 
      Magnetization\ of\ the\ Blocks\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*___  ___  ___  ___\ Shim\ ___  ___  ___  ___*) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(lsx = 10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ size\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(lsz = 0.1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ size\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(lss = per/2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Longitudinal\ size\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(px = 0;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ position\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(ps = per/6;\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      Longitudinal\ position\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(dz = 
        0.0;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ position\ above\ magnet\ array\ *) \), "\[IndentingNewLine]", \

    \(\(seg = {3, 5, 1};\)\ \ \ \ \ \ \ \ \  (*\ 
      Segmentation\ parameter\ *) \ \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\[IndentingNewLine] (*___  ___  ___  ___\ Generate\ \
the\ magnet\ array\ \ and\ shim\ ___  ___  ___  ___*) \[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\({all, shim, magnets} = 
        geom[];\)\[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  \
___\ \ Solve\ for\ the\ magnetization\ in\ the\ shim\ ___  ___  ___  ___\ *) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(RadSolve[all, 0.001, 100]\)}], "Input"],

Cell[BoxData[
    \({0.0008928158279188097`, 2.0515`, 1.2738613904904437`, 4}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Display the Geometry ", "Section"],

Cell[BoxData[
    \(\(radObjDrwQD3D[all];\)\)], "Input"],

Cell[BoxData[{
    \( (*\ 
      Only\ with\ Mathematica\ 4.0\ or\ later\ \ *) \[IndentingNewLine]\(<< 
        RealTime3D`;\)\), "\[IndentingNewLine]", 
    \(\(Show[Graphics3D[radObjDrw[all]]];\)\), "\[IndentingNewLine]", 
    \(\(<< Default3D`;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics3D[radObjDrw[all]]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.69013 .72644 -11.8649 0 ]
[.69013 .72644 12.3851 14 ]
[.81161 .67102 -4.8231 0 ]
[.81161 .67102 5.1769 14 ]
[.94762 .60896 -7.59053 0 ]
[.94762 .60896 8.40947 14 ]
[.81382 .73348 -7.5361 0 ]
[.81382 .73348 8.0889 14 ]
[.44409 .22867 -12.044 -14 ]
[.44409 .22867 12.206 0 ]
[.66168 .28101 -5.09604 -14 ]
[.66168 .28101 4.90396 0 ]
[.86416 .32972 -8.34411 -14 ]
[.86416 .32972 7.65589 0 ]
[.66048 .21852 -7.96256 -14 ]
[.66048 .21852 7.66244 0 ]
[.99519 .40507 0 -5.35885 ]
[.99519 .40507 24.25 8.64115 ]
[.99833 .45996 0 -5.42775 ]
[.99833 .45996 24.25 8.57225 ]
[1.0015 .51557 0 -5.49763 ]
[1.0015 .51557 18.25 8.50237 ]
[1.00472 .5719 0 -5.5685 ]
[1.00472 .5719 10 8.4315 ]
[1.06016 .4879 0 -5.44583 ]
[1.06016 .4879 14.3125 8.55417 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.65457 .73007 m
.99282 .57554 L
s
.25 Mabswid
.68986 .71394 m
.68973 .70769 L
s
gsave
.69013 .72644 -72.8649 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.81117 .65853 m
.81094 .65228 L
s
gsave
.81161 .67102 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94698 .59648 m
.94666 .59024 L
s
gsave
.94762 .60896 -68.5905 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.71895 .70065 m
.71886 .6969 L
s
.74885 .68699 m
.74874 .68325 L
s
.77957 .67296 m
.77945 .66921 L
s
.84366 .64368 m
.84352 .63993 L
s
.8771 .6284 m
.87694 .62466 L
s
.91153 .61267 m
.91135 .60893 L
s
.66153 .72689 m
.66146 .72314 L
s
.98352 .57979 m
.98331 .57604 L
s
gsave
.81382 .73348 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.30343 .20741 m
.98121 .37019 L
s
.25 Mabswid
.44401 .24117 m
.44397 .24742 L
s
gsave
.44409 .22867 -73.044 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.66192 .29351 m
.66204 .29976 L
s
gsave
.66168 .28101 -66.096 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.8647 .34221 m
.86497 .34846 L
s
gsave
.86416 .32972 -69.3441 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .25462 m
.5 .25837 L
s
.55496 .26782 m
.55499 .27157 L
s
.60893 .28078 m
.60898 .28453 L
s
.71397 .30601 m
.71407 .30976 L
s
.7651 .31829 m
.76522 .32204 L
s
.81534 .33036 m
.81548 .3341 L
s
.38697 .22747 m
.38692 .23122 L
s
.32884 .21351 m
.32876 .21726 L
s
.91321 .35386 m
.91339 .35761 L
s
.96089 .36532 m
.9611 .36906 L
s
gsave
.66048 .21852 -68.9626 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.98121 .37019 m
.99282 .57554 L
s
.25 Mabswid
.98302 .40221 m
.97693 .40079 L
s
gsave
.99519 .40507 -61 -9.35885 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.98613 .45722 m
.98003 .45585 L
s
gsave
.99833 .45996 -61 -9.42775 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.98928 .51294 m
.98317 .51163 L
s
gsave
1.0015 .51557 -61 -9.49763 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.99248 .56939 m
.98635 .56814 L
s
gsave
1.00472 .5719 -61 -9.5685 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.98364 .41316 m
.97999 .41231 L
s
.98426 .42413 m
.9806 .42329 L
s
.98488 .43513 m
.98123 .4343 L
s
.98551 .44616 m
.98185 .44533 L
s
.98676 .46831 m
.9831 .46749 L
s
.98739 .47942 m
.98372 .47862 L
s
.98802 .49057 m
.98435 .48977 L
s
.98865 .50174 m
.98498 .50095 L
s
.98992 .52418 m
.98625 .5234 L
s
.99056 .53544 m
.98689 .53466 L
s
.99119 .54673 m
.98752 .54596 L
s
.99183 .55805 m
.98816 .55729 L
s
.9824 .39129 m
.97875 .39043 L
s
.98179 .38041 m
.97814 .37954 L
s
gsave
1.06016 .4879 -61 -9.44583 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.04034 .42955 m
.02975 .62685 L
s
.02975 .62685 m
.65457 .73007 L
s
.65457 .73007 m
.65141 .54932 L
s
.65141 .54932 m
.04034 .42955 L
s
.30343 .20741 m
.98121 .37019 L
s
.98121 .37019 m
.99282 .57554 L
s
.99282 .57554 m
.29809 .43423 L
s
.29809 .43423 m
.30343 .20741 L
s
.04034 .42955 m
.02975 .62685 L
s
.02975 .62685 m
.29809 .43423 L
s
.29809 .43423 m
.30343 .20741 L
s
.30343 .20741 m
.04034 .42955 L
s
.65141 .54932 m
.98121 .37019 L
s
.98121 .37019 m
.99282 .57554 L
s
.99282 .57554 m
.65457 .73007 L
s
.65457 .73007 m
.65141 .54932 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.96849 .57068 m .95804 .37644 L .64507 .54726 L p 0 .208 .719 r
F P
0 g
s
.64507 .54726 m .64794 .71923 L .96849 .57068 L p 0 .208 .719 r
F P
0 g
s
.64794 .71923 m .64507 .54726 L .56827 .53219 L p 0 .35 .745 r
F P
0 g
s
.56827 .53219 m .64507 .54726 L .95804 .37644 L p 0 .444 1 r
F P
0 g
s
.95804 .37644 m .87437 .35653 L .56827 .53219 L p 0 .444 1 r
F P
0 g
s
.88304 .5533 m .87437 .35653 L .56827 .53219 L p 0 .2 .712 r
F P
0 g
s
.56827 .53219 m .56964 .70616 L .64794 .71923 L p 0 .35 .745 r
F P
0 g
s
.96849 .57068 m .64794 .71923 L .56964 .70616 L p 0 .451 1 r
F P
0 g
s
.56827 .53219 m .56964 .70616 L p .88304 .5533 L 0 .2 .712 r
F P
0 g
s
.56964 .70616 m .56827 .53219 L .56827 .53219 L p 0 .35 .745 r
F P
0 g
s
.56964 .70616 m .56827 .53219 L p .56827 .53219 L 0 .2 .712 r
F P
0 g
s
.56964 .70616 m .56964 .70616 L p .56827 .53219 L 0 .2 .712 r
F P
0 g
s
.56827 .53219 m .48942 .51673 L p .56964 .70616 L 0 .35 .745 r
F P
0 g
s
.56964 .70616 m .56964 .70616 L .56827 .53219 L 0 .35 .745 r
F
.56827 .53219 m .87437 .35653 L p .87437 .35653 L 0 .444 1 r
F P
0 g
s
.56827 .53219 m .56827 .53219 L p .87437 .35653 L 0 .444 1 r
F P
0 g
s
.87438 .35691 m .87437 .35653 L .88304 .5533 L 0 .351 .727 r
F
.87437 .35653 m .88304 .5533 L p .88304 .5533 L 0 .2 .712 r
F P
0 g
s
.56827 .53219 m .87437 .35653 L .88304 .5533 L 0 .2 .712 r
F
.87437 .35653 m .87437 .35653 L .88304 .5533 L F
.87437 .35653 m .88304 .5533 L p .88304 .5533 L 0 .351 .727 r
F P
0 g
s
.88304 .5533 m .87438 .35691 L .88304 .5533 L 0 .351 .727 r
F
.56827 .53219 m .87437 .35653 L .87437 .35653 L p 0 .2 .712 r
F P
0 g
s
.56827 .53219 m .87437 .35653 L .56827 .53219 L 0 .2 .712 r
F
.87437 .35653 m .78813 .336 L .48942 .51673 L p 0 .444 1 r
F P
0 g
s
.48942 .51673 m .56827 .53219 L p .87437 .35653 L 0 .444 1 r
F P
0 g
s
.87437 .35653 m .87437 .35653 L p .88304 .5533 L 0 .351 .727 r
F P
0 g
s
.78813 .336 m .87437 .35653 L p .88304 .5533 L 0 .351 .727 r
F P
0 g
s
.48921 .69274 m .56964 .70616 L p .56964 .70616 L 0 .35 .745 r
F P
0 g
s
.48942 .51673 m .48921 .69274 L p .56964 .70616 L 0 .35 .745 r
F P
0 g
s
.48921 .69274 m .48921 .69274 L p .56964 .70616 L 0 .35 .745 r
F P
0 g
s
.48921 .69274 m .40656 .67895 L p .40656 .67895 L 0 .451 1 r
F P
0 g
s
.88304 .5533 m .56964 .70616 L p .56827 .53219 L 0 .2 .712 r
F P
0 g
s
.48921 .69274 m .48942 .51673 L p .59968 .52346 L 0 .191 .705 r
F P
0 g
s
.61503 .63774 m .67613 .60658 L p .65659 .60658 L .683 0 .542 r
F P
0 g
s
.59968 .52346 m .66038 .52716 L .60097 .63521 L 0 .191 .705 r
F
.66038 .52716 m .79491 .53538 L .6618 .6039 L F
.66038 .52716 m .6618 .6039 L .60097 .63521 L F
.79491 .53538 m .88304 .5533 L p .71306 .61348 L 0 .451 1 r
F P
0 g
s
.60097 .63521 m .61503 .63774 L p .65659 .60658 L .683 0 .542 r
F P
0 g
s
.48921 .69274 m .60097 .63521 L p .61503 .63774 L 0 .451 1 r
F P
0 g
s
.54803 .67192 m .61503 .63774 L .63461 .64126 L 0 .451 1 r
F
.48921 .69274 m .61503 .63774 L .54803 .67192 L F
.63461 .64126 m .65024 .61978 L .71306 .61348 L F
.60097 .63521 m .48921 .69274 L p .59968 .52346 L 0 .191 .705 r
F P
0 g
s
.48942 .51673 m .48921 .69274 L .60097 .63521 L p 0 .191 .705 r
F P
0 g
s
.60097 .63521 m .6618 .6039 L p .60025 .57277 L 0 .191 .705 r
F P
0 g
s
.48942 .51673 m .60097 .63521 L .60025 .57277 L 0 .191 .705 r
F
.6618 .6039 m .79491 .53538 L p .66038 .52716 L F P
0 g
s
.48942 .51673 m .6618 .6039 L .66038 .52716 L 0 .191 .705 r
F
.48921 .69274 m .48942 .51673 L .40845 .50084 L p 0 .35 .745 r
F P
0 g
s
.48942 .51673 m .78813 .336 L .79491 .53538 L p 0 .191 .705 r
F P
0 g
s
.40656 .67895 m .48921 .69274 L p .48921 .69274 L 0 .35 .745 r
F P
0 g
s
.40845 .50084 m .40656 .67895 L p .48921 .69274 L 0 .35 .745 r
F P
0 g
s
.40656 .67895 m .40656 .67895 L p .48921 .69274 L 0 .35 .745 r
F P
0 g
s
.79491 .53538 m .78813 .336 L .48942 .51673 L p 0 .191 .705 r
F P
0 g
s
.40845 .50084 m .48942 .51673 L .78813 .336 L p 0 .444 1 r
F P
0 g
s
.40656 .67895 m .40845 .50084 L p .51495 .50662 L 0 .182 .696 r
F P
0 g
s
.40656 .67895 m .62711 .59741 L .48921 .69274 L 0 .451 1 r
F
.79491 .53538 m .6618 .6039 L p .62711 .59741 L F P
0 g
s
.6618 .6039 m .48921 .69274 L p .62711 .59741 L 0 .451 1 r
F P
0 g
s
.67613 .60658 m .6618 .6039 L p .65659 .60658 L .683 0 .542 r
F P
0 g
s
.51495 .50662 m .57365 .50981 L .51514 .61978 L 0 .182 .696 r
F
.57431 .58754 m .51514 .61978 L p .57365 .50981 L F P
0 g
s
.51514 .61978 m .40656 .67895 L p .51495 .50662 L 0 .182 .696 r
F P
0 g
s
.70397 .51688 m .57431 .58754 L p .57365 .50981 L 0 .182 .696 r
F P
0 g
s
.78813 .336 m .69921 .31483 L .40845 .50084 L p 0 .444 1 r
F P
0 g
s
.40845 .50084 m .69921 .31483 L .70397 .51688 L p 0 .182 .696 r
F P
0 g
s
.40845 .50084 m .40656 .67895 L .51514 .61978 L p 0 .182 .696 r
F P
0 g
s
.40656 .67895 m .40845 .50084 L .32527 .48453 L p 0 .35 .745 r
F P
0 g
s
.32527 .48453 m .32162 .66478 L .40656 .67895 L p 0 .35 .745 r
F P
0 g
s
.40656 .67895 m .32162 .66478 L p .46244 .61031 L 0 .451 1 r
F P
0 g
s
.51514 .61978 m .57431 .58754 L p .51503 .55655 L 0 .182 .696 r
F P
0 g
s
.40845 .50084 m .51514 .61978 L .51503 .55655 L 0 .182 .696 r
F
.57431 .58754 m .70397 .51688 L p .57365 .50981 L F P
0 g
s
.40845 .50084 m .57431 .58754 L .57365 .50981 L 0 .182 .696 r
F
.70397 .51688 m .51514 .61978 L p .46244 .61031 L 0 .451 1 r
F P
0 g
s
.51514 .61978 m .40656 .67895 L p .46244 .61031 L 0 .451 1 r
F P
0 g
s
.40656 .67895 m .70397 .51688 L .79491 .53538 L p 0 .451 1 r
F P
0 g
s
.70397 .51688 m .69921 .31483 L .40845 .50084 L p 0 .182 .696 r
F P
0 g
s
.32162 .66478 m .61008 .49779 L .70397 .51688 L p 0 .451 1 r
F P
0 g
s
.51514 .61978 m .44169 .60658 L p .51514 .62024 L .895 0 .369 r
F P
0 g
s
.6618 .6039 m .49938 .57353 L p .65659 .60658 L .683 0 .542 r
F P
0 g
s
.49938 .57353 m .57431 .58754 L .57432 .588 L .898 0 .368 r
F
.65024 .61978 m .6618 .6039 L .67613 .60658 L 0 .451 1 r
F
.67613 .60658 m .61503 .63774 L p .61503 .63774 L .501 0 .353 r
F P
0 g
s
.67613 .60658 m .67613 .60658 L p .61503 .63774 L .501 0 .353 r
F P
0 g
s
.60097 .63521 m .6618 .6039 L p .63461 .64126 L 0 .451 1 r
F P
0 g
s
.60097 .63521 m .6618 .6039 L .60097 .63521 L 0 .191 .705 r
F
.79491 .53538 m .6618 .6039 L p .6618 .6039 L F P
0 g
s
.6618 .6039 m .60097 .63521 L p .6618 .6039 L 0 .191 .705 r
F P
0 g
s
.79491 .53538 m .79491 .53538 L .6618 .6039 L 0 .191 .705 r
F
.49938 .57353 m .44169 .60658 L p .65659 .60658 L .683 0 .542 r
F P
0 g
s
.49938 .57466 m .49938 .57353 L p .66182 .60491 L .898 0 .368 r
F P
0 g
s
.65024 .61978 m .67613 .60658 L .71306 .61348 L 0 .451 1 r
F
.67615 .60768 m .67613 .60658 L p .61503 .63774 L .501 0 .353 r
F P
0 g
s
.67615 .60768 m .66182 .605 L p .66182 .60491 L .898 0 .368 r
F P
0 g
s
.66182 .605 m .49938 .57466 L p .66182 .60491 L .898 0 .368 r
F P
0 g
s
.57432 .588 m .6618 .6039 L .6618 .60408 L .898 0 .368 r
F
.57431 .58754 m .6618 .6039 L p .57432 .588 L F P
0 g
s
.60097 .63521 m .51514 .61978 L p .60098 .6362 L .895 0 .369 r
F P
0 g
s
.51514 .62024 m .60098 .6362 L .51514 .61978 L .895 0 .369 r
F
.61503 .63774 m .61505 .63882 L .67615 .60768 L p .501 0 .353 r
F P
0 g
s
.61505 .63882 m .61503 .63774 L .60097 .63521 L p .895 0 .369 r
F P
0 g
s
.6618 .6039 m .79491 .53538 L p .71306 .61348 L 0 .451 1 r
F P
0 g
s
.67613 .60658 m .67615 .60768 L p .66182 .60491 L .898 0 .368 r
F P
0 g
s
.6618 .6039 m .67613 .60658 L p .66182 .60491 L .898 0 .368 r
F P
0 g
s
.44169 .60658 m .60097 .63521 L p .65659 .60658 L .683 0 .542 r
F P
0 g
s
.60098 .6362 m .61505 .63882 L .60097 .63521 L .895 0 .369 r
F
.48921 .69274 m .48921 .69274 L p .40656 .67895 L 0 .451 1 r
F P
0 g
s
.56964 .70616 m .88304 .5533 L .96849 .57068 L p 0 .451 1 r
F P
0 g
s
.56964 .70616 m .88304 .5533 L p .88304 .5533 L 0 .2 .712 r
F P
0 g
s
.56964 .70616 m .56964 .70616 L p .88304 .5533 L 0 .2 .712 r
F P
0 g
s
.88304 .5533 m .56964 .70616 L .48921 .69274 L p 0 .451 1 r
F P
0 g
s
.32527 .48453 m .40845 .50084 L .69921 .31483 L p 0 .444 1 r
F P
0 g
s
.69921 .31483 m .60747 .29299 L .32527 .48453 L p 0 .444 1 r
F P
0 g
s
.32527 .48453 m .60747 .29299 L .61008 .49779 L p 0 .171 .685 r
F P
0 g
s
.61008 .49779 m .60747 .29299 L .32527 .48453 L p 0 .171 .685 r
F P
0 g
s
.61008 .49779 m .32162 .66478 L .32527 .48453 L p 0 .171 .685 r
F P
0 g
s
.32527 .48453 m .32162 .66478 L .61008 .49779 L p 0 .171 .685 r
F P
0 g
s
.32162 .66478 m .32527 .48453 L .23979 .46776 L p 0 .35 .745 r
F P
0 g
s
.23979 .46776 m .32527 .48453 L .60747 .29299 L p 0 .444 1 r
F P
0 g
s
.23979 .46776 m .23427 .6502 L .32162 .66478 L p 0 .35 .745 r
F P
0 g
s
.5131 .47806 m .23427 .6502 L .23979 .46776 L p 0 .159 .673 r
F P
0 g
s
.60747 .29299 m .51279 .27046 L .23979 .46776 L p 0 .444 1 r
F P
0 g
s
.23979 .46776 m .51279 .27046 L .5131 .47806 L p 0 .159 .673 r
F P
0 g
s
.5131 .47806 m .51279 .27046 L .23979 .46776 L p 0 .159 .673 r
F P
0 g
s
.23979 .46776 m .23427 .6502 L .5131 .47806 L p 0 .159 .673 r
F P
0 g
s
.23427 .6502 m .23979 .46776 L .15191 .45052 L p 0 .35 .745 r
F P
0 g
s
.15191 .45052 m .14442 .63521 L .14442 .63521 L p 0 .145 .659 r
F P
0 g
s
.15191 .45052 m .14442 .63521 L .15191 .45052 L 0 .145 .659 r
F
.15191 .45052 m .14442 .63521 L .23427 .6502 L p 0 .35 .745 r
F P
0 g
s
.5131 .47806 m .23427 .6502 L .14442 .63521 L p 0 .451 1 r
F P
0 g
s
.15191 .45052 m .23979 .46776 L .51279 .27046 L p 0 .444 1 r
F P
0 g
s
.15191 .45052 m .14442 .63521 L .41288 .45768 L 0 .145 .659 r
F
.14442 .63521 m .15191 .45052 L .06152 .43279 L p 0 .35 .745 r
F P
0 g
s
.06152 .43279 m .05196 .61978 L .14442 .63521 L p 0 .35 .745 r
F P
0 g
s
.14442 .63521 m .41288 .45768 L .5131 .47806 L p 0 .451 1 r
F P
0 g
s
.14442 .63521 m .41288 .45768 L p .41288 .45768 L 0 .145 .659 r
F P
0 g
s
.14442 .63521 m .14442 .63521 L .41288 .45768 L 0 .145 .659 r
F
.61008 .49779 m .32162 .66478 L .23427 .6502 L p 0 .451 1 r
F P
0 g
s
.51279 .27046 m .41501 .24718 L .15191 .45052 L p 0 .444 1 r
F P
0 g
s
.41501 .24718 m .51279 .27046 L .5131 .47806 L p 0 .351 .727 r
F P
0 g
s
.41501 .24718 m .15191 .45052 L p .41288 .45768 L 0 .145 .659 r
F P
0 g
s
.15191 .45052 m .41501 .24718 L p .41501 .24718 L 0 .444 1 r
F P
0 g
s
.06152 .43279 m .15191 .45052 L p .41501 .24718 L 0 .444 1 r
F P
0 g
s
.15191 .45052 m .15191 .45052 L p .41501 .24718 L 0 .444 1 r
F P
0 g
s
.41288 .45768 m .14442 .63521 L .15191 .45052 L p 0 .145 .659 r
F P
0 g
s
.41501 .24718 m .31399 .22313 L .06152 .43279 L p 0 .444 1 r
F P
0 g
s
.15191 .45052 m .41501 .24718 L .41501 .24718 L p 0 .145 .659 r
F P
0 g
s
.41501 .24718 m .41288 .45768 L p .15191 .45052 L 0 .145 .659 r
F P
0 g
s
.15191 .45052 m .41501 .24718 L .15191 .45052 L 0 .145 .659 r
F
.5131 .47806 m .41288 .45768 L .41501 .24718 L p 0 .351 .727 r
F P
0 g
s
.41288 .45768 m .41501 .24718 L .41501 .24718 L p 0 .145 .659 r
F P
0 g
s
.41288 .45768 m .41288 .45768 L .41501 .24718 L 0 .145 .659 r
F
.23427 .6502 m .5131 .47806 L .61008 .49779 L p 0 .451 1 r
F P
0 g
s
.30924 .4366 m .05196 .61978 L .06152 .43279 L p 0 .129 .642 r
F P
0 g
s
.06152 .43279 m .31399 .22313 L .30924 .4366 L p 0 .129 .642 r
F P
0 g
s
.44169 .60658 m .44168 .60768 L .61505 .63882 L p .895 0 .369 r
F P
0 g
s
.67615 .60768 m .61505 .63882 L .44168 .60768 L p .683 0 .542 r
F P
0 g
s
.41288 .45768 m .14442 .63521 L .05196 .61978 L p 0 .451 1 r
F P
0 g
s
0 0 0 r
.58117 .63273 m
.58117 .63273 L
s
.58117 .63273 m
.58117 .63273 L
s
.58117 .63273 m
.58117 .63273 L
s
.63502 .62864 m
.63502 .62864 L
s
.63502 .62864 m
.63502 .62864 L
s
.53448 .61035 m
.53448 .61035 L
s
.53448 .61035 m
.62087 .62606 L
s
.62087 .62606 m
.62087 .62606 L
s
.62087 .62606 m
.62087 .62606 L
s
.62087 .62606 m
.62087 .62606 L
s
.62087 .62606 m
.62087 .62606 L
s
.62087 .62606 m
.63502 .62864 L
s
.63502 .62864 m
.63502 .62864 L
s
.63502 .62864 m
.63502 .62864 L
s
.63502 .62864 m
.63502 .62864 L
s
.54691 .62658 m
.54691 .62658 L
s
.54691 .62658 m
.54691 .62658 L
s
.54691 .62658 m
.54691 .62658 L
s
.05196 .61978 m .30924 .4366 L .41288 .45768 L p 0 .451 1 r
F P
0 g
s
0 0 0 r
.51224 .62035 m
.51224 .62035 L
s
.51224 .62035 m
.51224 .62035 L
s
.51224 .62035 m
.51224 .62035 L
s
.65539 .61826 m
.65539 .61826 L
s
.65539 .61826 m
.65539 .61826 L
s
.64114 .61564 m
.64114 .61564 L
s
.64114 .61564 m
.64114 .61564 L
s
.64114 .61564 m
.64114 .61564 L
s
.64114 .61564 m
.64114 .61564 L
s
.64114 .61564 m
.65539 .61826 L
s
.65539 .61826 m
.65539 .61826 L
s
.65539 .61826 m
.65539 .61826 L
s
.65539 .61826 m
.65539 .61826 L
s
.47717 .61405 m
.47717 .61405 L
s
.47717 .61405 m
.47717 .61405 L
s
.47717 .61405 m
.47717 .61405 L
s
.49938 .57466 m .44168 .60768 L .44169 .60658 L p .458 0 .344 r
F P
0 g
s
.44169 .60658 m .49938 .57353 L .49938 .57466 L p .458 0 .344 r
F P
0 g
s
.44168 .60768 m .49938 .57466 L .67615 .60768 L p .683 0 .542 r
F P
0 g
s
0 0 0 r
.47717 .61405 m
.53559 .58142 L
s
.47976 .58589 m
.47976 .58589 L
s
.47976 .58589 m
.55421 .59961 L
s
.46053 .59689 m
.46054 .59689 L
s
.46054 .59689 m
.53448 .61035 L
s
.53559 .58142 m
.53559 .58142 L
s
.55421 .59961 m
.64114 .61564 L
s
.55421 .59961 m
.55421 .59961 L
s
.51224 .62035 m
.57136 .58811 L
s
.57136 .58811 m
.57136 .58811 L
s
.54691 .62658 m
.60671 .59471 L
s
.60671 .59471 m
.60671 .59471 L
s
.58117 .63273 m
.64163 .60123 L
s
.64163 .60123 m
.64163 .60123 L
s
.64163 .60123 m
.64163 .60123 L
s
.64162 .60012 m
.64163 .60123 L
s
.64162 .60012 m
.64162 .60012 L
s
.64162 .60012 m
.64162 .60012 L
s
.64162 .60012 m
.64162 .60012 L
s
.87437 .35653 m .95804 .37644 L .96849 .57068 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.46053 .59689 m
.46053 .59689 L
s
.46053 .59689 m
.46054 .59578 L
s
.46054 .59578 m
.46054 .59578 L
s
.46054 .59578 m
.46054 .59578 L
s
.46054 .59578 m
.46054 .59578 L
s
.60671 .59471 m
.60671 .59471 L
s
.60669 .59359 m
.60671 .59471 L
s
.60669 .59359 m
.60669 .59359 L
s
.60669 .59359 m
.60669 .59359 L
s
.60669 .59359 m
.60669 .59359 L
s
.60669 .59359 m
.60669 .59359 L
s
.57136 .58811 m
.57136 .58811 L
s
.57135 .58698 m
.57136 .58811 L
s
.57135 .58698 m
.57135 .58698 L
s
.57135 .58698 m
.57135 .58698 L
s
.57135 .58698 m
.57135 .58698 L
s
.57135 .58698 m
.57135 .58698 L
s
.57135 .58698 m
.57135 .58698 L
s
.47976 .58589 m
.47976 .58589 L
s
.47976 .58589 m
.47977 .58476 L
s
.47977 .58476 m
.47977 .58476 L
s
.47977 .58476 m
.47977 .58476 L
s
.47977 .58476 m
.47977 .58476 L
s
.53559 .58142 m
.53559 .58142 L
s
.53558 .5803 m
.53559 .58142 L
s
.53558 .5803 m
.53558 .5803 L
s
.53558 .5803 m
.53558 .5803 L
s
.53558 .5803 m
.53558 .5803 L
s
.53558 .5803 m
.53558 .5803 L
s
.96849 .57068 m .88304 .5533 L .87437 .35653 L p 0 .351 .727 r
F P
0 g
s
.88304 .5533 m .79491 .53538 L .78813 .336 L p 0 .351 .727 r
F P
0 g
s
.69921 .31483 m .78813 .336 L .79491 .53538 L p 0 .351 .727 r
F P
0 g
s
.79491 .53538 m .70397 .51688 L .69921 .31483 L p 0 .351 .727 r
F P
0 g
s
.60747 .29299 m .69921 .31483 L .70397 .51688 L p 0 .351 .727 r
F P
0 g
s
.70397 .51688 m .61008 .49779 L .60747 .29299 L p 0 .351 .727 r
F P
0 g
s
.51279 .27046 m .60747 .29299 L .61008 .49779 L p 0 .351 .727 r
F P
0 g
s
.61008 .49779 m .5131 .47806 L .51279 .27046 L p 0 .351 .727 r
F P
0 g
s
.31399 .22313 m .41501 .24718 L .41288 .45768 L p 0 .351 .727 r
F P
0 g
s
.41288 .45768 m .30924 .4366 L .31399 .22313 L p 0 .351 .727 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.30343 .20741 m
.98121 .37019 L
s
.98121 .37019 m
.99282 .57554 L
s
.99282 .57554 m
.29809 .43423 L
s
.29809 .43423 m
.30343 .20741 L
s
.04034 .42955 m
.02975 .62685 L
s
.02975 .62685 m
.29809 .43423 L
s
.29809 .43423 m
.30343 .20741 L
s
.30343 .20741 m
.04034 .42955 L
s
.003 w
[ ] 0 setdash
.98121 .37019 m
.99282 .57554 L
s
.25 Mabswid
.98302 .40221 m
.97693 .40079 L
s
gsave
.99519 .40507 -61 -9.35885 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.98613 .45722 m
.98003 .45585 L
s
gsave
.99833 .45996 -61 -9.42775 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.98928 .51294 m
.98317 .51163 L
s
gsave
1.0015 .51557 -61 -9.49763 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.99248 .56939 m
.98635 .56814 L
s
gsave
1.00472 .5719 -61 -9.5685 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.98364 .41316 m
.97999 .41231 L
s
.98426 .42413 m
.9806 .42329 L
s
.98488 .43513 m
.98123 .4343 L
s
.98551 .44616 m
.98185 .44533 L
s
.98676 .46831 m
.9831 .46749 L
s
.98739 .47942 m
.98372 .47862 L
s
.98802 .49057 m
.98435 .48977 L
s
.98865 .50174 m
.98498 .50095 L
s
.98992 .52418 m
.98625 .5234 L
s
.99056 .53544 m
.98689 .53466 L
s
.99119 .54673 m
.98752 .54596 L
s
.99183 .55805 m
.98816 .55729 L
s
.9824 .39129 m
.97875 .39043 L
s
.98179 .38041 m
.97814 .37954 L
s
gsave
1.06016 .4879 -61 -9.44583 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00Y@3oool3000007P0oooo002U0?ooo`030>k^kP00
0000k^k^07P0oooo001`0?ooo`@0000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0Y
0?ooo`030000003oool0oooo07L0oooo001`0?ooo`0;0<c<c03^k^h0oooo0<c<c01EEED0oooo0000
002HV9P0oooo09RHV0000000:P3oool00`3^k^h000000>k^kP1h0?ooo`00L@3oool00`3<c<`0k^k^
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000:P3oool304A4A7P0oooo001Y0?ooo`L00000
0P3oool01@2YZJT0k^k^0?ooo`3oool0000000<0oooo00<000000?ooo`3oool09`3oool01@27QhL0
A4A40?ooo`0b<S80ZJVY07L0oooo001=0?ooo`@000008@3oool01@3MgMd0IVIV0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool09P3oool01`3<c<`000000>k^kP3oool0c<c<0000003<c<`0MP3o
ool004`0oooo00<000000?ooo`0000000P3oool4000001/0oooo00@0MgMg0?ooo`3oool000000P3o
ool01@000000oooo0?ooo`3oool0000002P0oooo0P0000000`0b<S80oooo00000002000007H0oooo
001=0?ooo`030000003oool0oooo00@0oooo1P00000F0?ooo`040000002HV9P0V9RH00000080oooo
00D0000009RHV03oool0V9RH0000002U0?ooo`00BP3oool00`000000oooo0?ooo`0<0?ooo`H00000
4@3oool0102HV9P000000000002HV9P20?ooo`0509RHV000000000000000002HV9P0Y@3oool004T0
oooo00H000000?ooo`3oool0oooo0000003oool4000000/0oooo1000002n0?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`80000000@0026T00000000FKX005Vj1@00000:0?ooo`@00000^P3oool0
04H0oooo00<000000?ooo`3oool0103oool010000000026T000QY0000007001I^P@000001`3oool0
0`000000oooo0?ooo`0400000;H0oooo00150?ooo`030000003oool0oooo00@0oooo0P000002000Q
Y00300000000FKX005Vj00T005Vj1000000:0?ooo`@00000/P3oool004@0oooo00<000000?ooo`3o
ool0103oool00`000000026T000QY002000QY00300000000FKX005Vj00d005Vj1@0000090?ooo`D0
0000[@3oool004T0oooo0P000002000QY004000000008J@0026T000001@005Vj100000090?ooo`H0
0000Z03oool00440oooo0P0000050?ooo`03000000008J@0026T0080026T00@00000000QY0008J@0
00006000FKX4000000D0oooo00@000000?ooo`3oool0oooo1@00000/0?ooo`0509RHV00000000000
0000002HV9P0M03oool00400oooo00<000000?ooo`3oool0103oool00`000000026T000QY003000Q
Y004000000008J@0026T000001T005Vj00<00000001I^P00FKX01000000:0?ooo`@00000:03oool0
1@000000V9RH0?ooo`2HV9P0000007@0oooo00160?ooo`03000000008J@0026T00@0026T00@00000
000QY0008J@000006@00FKX00`00000005Vj001I^P04001I^P@000002P3oool4000002@0oooo00D0
00000?ooo`3oool0oooo0000001d0?ooo`00?P3oool00`000000oooo0?ooo`040?ooo`0300000000
8J@0026T00P0026T00<00000001I^P00FKX05`00FKX00`00000005Vj001I^P08001I^PD000001P3o
ool00`000000oooo0?ooo`0400000200oooo00D000000?ooo`3oool0oooo0000001d0?ooo`00?@3o
ool00`000000oooo0?ooo`030?ooo`80000020008J@010000000026T000QY000000I001I^P030000
0000FKX005Vj00d005Vj100000090?ooo`D000006`3oool01@000000oooo0?ooo`3oool0000007@0
oooo000l0?ooo`030000003oool0oooo00<0oooo00<00000000QY0008J@020008J@010000000026T
000QY000000I001I^P0300000000FKX005Vj014005Vj100000090?ooo`H000005P3oool01@000000
oooo0?ooo`3oool0000007@0oooo000j0?ooo`030000003oool0oooo00@0oooo00<00000000QY000
8J@02@008J@010000000026T000QY000000I001I^P0300000000FKX005Vj01D005Vj100000080?oo
o`D00000503oool01@000000V9RH0?ooo`2HV9P0000007@0oooo000i0?ooo`030000003oool0oooo
00@0oooo00<00000000QY0008J@02P008J@010000000026T000QY000000I001I^P0300000000FKX0
05Vj01H005Vj00<00000001I^P00FKX0100000090?ooo`D000003`3oool01@2HV9P0000000000000
0000V9RH07@0oooo000h0?ooo`030000003oool0oooo00@0oooo00<00000000QY0008J@03P008J@0
0`00000005Vj001I^P0G001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX01000FKX4
000000X0oooo100000240?ooo`00?@3oool200000140026T00<00000001I^P00FKX05`00FKX00`00
000005Vj001I^P0F001I^P0300000000FKX005Vj00P005Vj1@0000090?ooo`@00000P03oool003D0
oooo0P0000050?ooo`03000000008J@0026T00h0026T00@00000000QY0008J@000006@00FKX00`00
000005Vj001I^P0F001I^P0300000000FKX005Vj00d005Vj100000050?ooo`040000003oool0oooo
0?ooo`D00000N`3oool003@0oooo00<000000?ooo`3oool0103oool00`000000026T000QY00?000Q
Y004000000008J@0026T000001T005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0A
001I^P@000002@3oool6000007H0oooo000j0?ooo`03000000008J@0026T0100026T00@00000000Q
Y0008J@000006@00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01D005Vj10000009
0?ooo`@00000:`3oool4000000030;Zj^P3oool0V9RH00<0000000<0V9RH0?ooo`3oool0?03oool0
0380oooo00<000000?ooo`3oool0103oool00`000000026T000QY00D000QY00300000000FKX005Vj
01L005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj
00D000001P3oool00`000000oooo00000003000002L0oooo00/0c<c<0>k^kP3oool0c<c<05EEE@3o
ool0000009RHV03oool0V9RH0000000n0?ooo`00<@3oool00`000000oooo0?ooo`030?ooo`800000
5`008J@00`00000005Vj001I^P0G001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX0
5P00FKX00`00000005Vj001I^P05001I^PD000001`3oool5000002<0oooo00<0c<c<0>k^kP3oool0
0P3oool01@000000oooo0?ooo`3oool0000003h0oooo000`0?ooo`030000003oool0oooo00<0oooo
00<00000000QY0008J@050008J@010000000026T000QY000000I001I^P0300000000FKX005Vj01H0
05Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0:001I^P@00000203oool400000200
oooo00D0ZJVY0>k^kP3oool0oooo000000030?ooo`030000003oool0oooo03`0oooo000^0?ooo`03
0000003oool0oooo00@0oooo00<00000000QY0008J@05@008J@010000000026T000QY000000I001I
^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0>001I
^PD000001@3oool00`000000oooo00000004000001/0oooo00D0gMgM06IVIP3oool0oooo00000003
0?ooo`030000003oool0oooo03`0oooo000]0?ooo`030000003oool0oooo00@0oooo00<00000000Q
Y0008J@05P008J@010000000026T000QY000000I001I^P0300000000FKX005Vj01H005Vj00<00000
001I^P00FKX05P00FKX00`00000005Vj001I^P0C001I^P@000001`3oool6000001@0oooo00@0MgMg
0?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000003h0oooo000/0?ooo`030000003o
ool0oooo00@0oooo00<00000000QY0008J@06P008J@00`00000005Vj001I^P0G001I^P0300000000
FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0D001I^P0300000000
FKX005Vj00@000001`3oool400000180oooo00@0000009RHV02HV9P000000P3oool01@000000V9RH
0?ooo`2HV9P0000003h0oooo000a0?ooo`8000007@008J@00`00000005Vj001I^P0G001I^P030000
0000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0D001I^P030000
0000FKX005Vj00@005Vj100000060?ooo`D000003P3oool0102HV9P000000000002HV9P20?ooo`05
09RHV000000000000000002HV9P0?P3oool002T0oooo0P0000050?ooo`03000000008J@0026T01X0
026T00@00000000QY0008J@000006@00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj
01H005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P08001I^P<00000203oool50000
0580oooo000X0?ooo`030000003oool0oooo00@0oooo00<00000000QY0008J@06`008J@010000000
026T000QY000000I001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00
000005Vj001I^P0D001I^P0300000000FKX005Vj00/005Vj100000080?ooo`D00000CP3oool002h0
oooo00<00000000QY0008J@070008J@00`000000026T0000000J001I^P0300000000FKX005Vj01H0
05Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj00l0
05Vj100000080?ooo`H00000B@3oool002H0oooo00<000000?ooo`3oool00`3oool200000240026T
00<00000001I^P00FKX06000FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj
00<00000001I^P00FKX05000FKX00`00000005Vj001I^P0C001I^P@000002@3oool6000004@0oooo
000U0?ooo`030000003oool0oooo00<0oooo00<00000000QY0008J@08@008J@00`00000005Vj001I
^P0H001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I
^P0D001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX01@0000080?ooo`D00000@@3o
ool002@0oooo00<000000?ooo`3oool00`3oool00`000000026T000QY00P000QY003000000008J@0
000001X005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0F001I^P0300000000FKX0
05Vj01@005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P05001I^P@00000203oool4
000003h0oooo000R0?ooo`030000003oool0oooo00@0oooo00<00000000QY0008J@08@008J@00`00
0000026T0000000J001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00
000005Vj001I^P0D001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX02@00FKX40000
00@0oooo00@000000?ooo`3oool0oooo1@00000i0?ooo`008@3oool00`000000oooo0?ooo`040?oo
o`03000000008J@0026T0280026T00<00000000QY00000006P00FKX00`00000005Vj001I^P0F001I
^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P0D001I
^P0300000000FKX005Vj00d005Vj1@0000070?ooo`D00000=@3oool00200oooo00<000000?ooo`3o
ool00`3oool2000002D0026T00<00000000QY00000006P00FKX00`00000005Vj001I^P0F001I^P03
00000000FKX005Vj01H005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P0D001I^P03
00000000FKX005Vj018005Vj100000070?ooo`H00000<03oool002D0oooo00<00000000QY0008J@0
9`008J@00`00000005Vj001I^P0H001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX0
5P00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX0
4`00FKX00`00000005Vj001I^P05000000L0oooo1P00000[0?ooo`007@3oool2000000D0oooo00<0
0000000QY0008J@09P008J@00`000000026T0000000J001I^P0300000000FKX005Vj01H005Vj00<0
0000001I^P00FKX05P00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01@005Vj00<0
0000001I^P00FKX04`00FKX00`00000005Vj001I^P05001I^P@000001`3oool5000002P0oooo000L
0?ooo`030000003oool0oooo00@0oooo00<00000000QY0008J@09`008J@00`000000026T0000000J
001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E
001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P09
001I^P@000001`3oool4000002D0oooo000R0?ooo`03000000008J@0026T02L0026T00@00000000Q
Y0008J@000006P00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj00<00000
001I^P00FKX05@00FKX00`00000005Vj001I^P0C001I^P0300000000FKX005Vj01<005Vj00<00000
001I^P00FKX03@00FKX5000000D0oooo0`00000S0?ooo`006P3oool00`000000oooo0?ooo`030?oo
o`800000:P008J@010000000026T000QY000000J001I^P0300000000FKX005Vj01H005Vj00<00000
001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000FKX005Vj01<005Vj00<00000
001I^P00FKX04`00FKX00`00000005Vj001I^P0B001I^P8000000P3oool010000000oooo0?ooo`00
000S0?ooo`006@3oool00`000000oooo0?ooo`030?ooo`03000000008J@0026T02d0026T00<00000
001I^P00FKX06000FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj00<00000
001I^P00FKX05@00FKX00`00000005Vj001I^P0C001I^P0300000000FKX005Vj01<005Vj00<00000
001I^P00FKX04`00FKX00`000000oooo000000020?ooo`8000008`3oool001P0oooo00<000000?oo
o`3oool00`3oool00`000000026T000QY00[000QY004000000008J@0026T000001X005Vj00<00000
001I^P00FKX05P00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01D005Vj00<00000
001I^P00FKX04`00FKX00`00000005Vj001I^P0C001I^P0300000000FKX005Vj01<005Vj00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`005`3oool00`000000oooo0?ooo`030?oo
o`03000000008J@0026T02`0026T00@00000000QY0008J@000006P00FKX00`00000005Vj001I^P0F
001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05@00FKX00`00000005Vj001I^P0C
001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0240oooo000F0?ooo`030000003oool0oooo00<0oooo00<00000000Q
Y0008J@0;@008J@010000000026T000QY000000J001I^P0300000000FKX005Vj01H005Vj00<00000
001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000FKX005Vj01@005Vj00<00000
001I^P00FKX04`00FKX00`00000005Vj001I^P0B001I^P030000003oool0oooo0080oooo0P00000S
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`800000<0008J@010000000026T000QY000000J
001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E
001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0B
001I^P030000003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool001T0oooo00<00000000Q
Y0008J@0<`008J@00`00000005Vj001I^P0H001I^P0300000000FKX005Vj01H005Vj00<00000001I
^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000FKX005Vj01@005Vj00<00000001I
^P00FKX04`00FKX00`00000005Vj001I^P0B001I^P030000003oool0oooo0080oooo0P00000S0?oo
o`004P3oool2000000@0oooo00<00000000QY0008J@0<@008J@010000000026T000QY000000J001I
^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I
^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0B001I
^P030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool3000000030?ooo`0@41000000
0080000000<0V9RH0?ooo`3oool02@3oool00140oooo00<000000?ooo`3oool00`3oool00`000000
026T000QY00b000QY004000000008J@0026T000001X005Vj00<00000001I^P00FKX05P00FKX00`00
000005Vj001I^P0F001I^P0300000000FKX005Vj01D005Vj00<00000001I^P00FKX05000FKX00`00
000005Vj001I^P0C001I^P0300000000FKX005Vj018005Vj00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<0V9RH0000003oool02P3oool001H0
oooo00<00000000QY0008J@0<`008J@010000000026T000QY000000J001I^P0300000000FKX005Vj
01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000FKX005Vj
01@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0C001I^P030000003oool0oooo
0080oooo0P00000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool000l0
oooo00<000000?ooo`3oool00P3oool2000003H0026T00@00000000QY0008J@000006P00FKX00`00
000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05@00FKX00`00
000005Vj001I^P0D001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`00
0000oooo0?ooo`020?ooo`800000103oool7000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`003P3oool00`000000oooo0?ooo`020?ooo`03000000008J@0026T03T0
026T00<00000001I^P00FKX06000FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H0
05Vj00<00000001I^P00FKX05@00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01<0
05Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool00`2HV9P000000?ooo`0:0?ooo`003@3oool00`000000oooo
0?ooo`020?ooo`03000000008J@0026T03X0026T00<00000001I^P00FKX06000FKX00`00000005Vj
001I^P0F001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05@00FKX00`00000005Vj
001I^P0D001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`000000oooo
0?ooo`020?ooo`8000003`3oool00`000000oooo0?ooo`040000000309RHV03oool0oooo00T0oooo
000;0?ooo`030000003oool0oooo00<0oooo00<00000000QY0008J@0>0008J@010000000026T000Q
Y000000J001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj
001I^P0E001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj
001I^P0C001I^P030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool01@000000oooo
0?ooo`1gMgL0EEEE00h0oooo000:0?ooo`800000103oool00`000000026T000QY00i000QY0040000
00008J@0026T000001X005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0F001I^P03
00000000FKX005Vj01D005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P0C001I^P03
00000000FKX005Vj01<005Vj00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`03
024Q8@000000oooo0080oooo00@0410@000000000000<S8b2`3oool000X0oooo00<000000?ooo`3o
ool00`00000l000QY080000000<0026T00000000FKX06@00FKX00`00000005Vj001I^P0F001I^P03
00000000FKX005Vj01H005Vj00<00000001I^P00FKX05@00FKX00`00000005Vj001I^P0D001I^P03
00000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`020?ooo`80
00008P3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000026T000QY00i000QY0030000
00008J@0026T00D000005`00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj
00<00000001I^P00FKX05@00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01<005Vj
00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo
000:0?ooo`030000003oool0oooo0080oooo00<00000000QY0008J@0>0008J@010000000026T000Q
Y0000005001co`D000004P00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj
00<00000001I^P00FKX05@00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01<005Vj
00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo
000?0?ooo`03000000008J@0026T03H0026T00<00000000QY0008J@00P00000;001co`H000003000
FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX05@00
FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00
FKX00`000000oooo0?ooo`020?ooo`8000008P3oool000X0oooo00<000000?ooo`3oool00P3oool0
0`000000026T000QY00e000QY004000000008J@0026T0000018007?o1P000007001I^P0300000000
FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000
FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0C001I^P030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0803oool000X0oooo00<000000?ooo`3oool00P3oool0
0`000000026T000QY00d000QY004000000008J@0026T000001T007?o1@000002001I^P0300000000
FKX005Vj01H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000
FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0C001I^P030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0803oool000T0oooo00<000000?ooo`3oool00`3oool0
0`000000026T000QY00b000QY003000000008J@0026T008000007`00Lol6000001D005Vj00<00000
001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000FKX005Vj01@005Vj00<00000
001I^P00FKX05000FKX00`00000005Vj001I^P0B001I^P030000003oool0oooo0080oooo0P00000?
0?ooo`<0000000<0oooo09RHV00000000P0000000`2HV9P0oooo0?ooo`080?ooo`002@3oool00`00
0000oooo0?ooo`030?ooo`03000000008J@0026T0340026T00@00000000QY0008J@000009P00Lol6
0000010005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0E001I^P0300000000FKX0
05Vj01@005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P0B001I^P030000003oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P0
00002P3oool000l0oooo00<00000000QY0008J@0<0008J@010000000026T00000000000Q001co`03
00000000Lol007?o00P007?o1P00000;001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00
FKX05@00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00
FKX04P00FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`030?ooo`03
000000008J@0026T02d0026T0P000002000QY00300000000Lol007?o01l007?o00<00000001co`00
Lol03`00Lol6000000H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0F001I^P03
00000000FKX005Vj01<005Vj00<00000001I^P00FKX05000FKX00`00000005Vj001I^P0B001I^P03
0000003oool0oooo0080oooo0P0000050?ooo`L00000103oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo00<0oooo00<00000000QY000
8J@0;0008J@01@000000026T000QY0008J@00000020007?o0P00000G001co`H0000000<005Vj0000
0000FKX05`00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01<005Vj00<00000001I
^P00FKX05000FKX00`00000005Vj001I^P0B001I^P030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00090?oo
o`030000003oool0oooo00<0oooo00<00000000QY0008J@0:`008J@00`000000026T000QY0020000
020007?o00<00000001co`00Lol07000Lol6000001D005Vj00<00000001I^P00FKX05P00FKX00`00
000005Vj001I^P0C001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`00
0000oooo0?ooo`020?ooo`8000003`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00P0oooo00090?ooo`030000003oool0oooo00<0oooo00<00000000QY0008J@0:@008J@01@00
0000026T000QY0008J@00000020007?o0P00000O001co`0300000000Lol007?o008007?o1P00000@
001I^P0300000000FKX005Vj01H005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0D
001I^P0300000000FKX005Vj01<005Vj00<000000?ooo`3oool00P3oool2000000l0oooo00P00000
0?ooo`3oool0000009RHV03oool0V9RH000000X0oooo000>0?ooo`03000000008J@0026T02T0026T
00<00000000QY0008J@00P00000P001co`0300000000Lol007?o01d007?o0P00000:001co`H00000
2`00FKX00`00000005Vj001I^P0F001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX0
5000FKX00`00000005Vj001I^P0C001I^P030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool01@0Q8B4000000?ooo`3oool0V9RH00H00000203oool000T0oooo00<000000?ooo`3oool0
0P3oool00`000000026T000QY00X000QY004000000008J@0026T0000020007?o0P00000N001co`80
00004@00Lol6000000H005Vj00<00000001I^P00FKX05P00FKX00`00000005Vj001I^P0D001I^P03
00000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`020?ooo`80
00004`3oool01P2YZJT0<S8b0?ooo`3oool0k^k^038b<PP0oooo00090?ooo`030000003oool0oooo
0080oooo00<00000000QY0008J@09P008J@01@000000026T000QY0008J@00000020007?o00<00000
001co`00Lol07@00Lol00`00000007?o001co`0F001co`H0000000<005Vj00000000FKX05`00FKX0
0`00000005Vj001I^P0D001I^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<0IVIV07MgM`3oool02P3oool0
00T0oooo00<000000?ooo`3oool00P3oool00`000000026T000QY00U000QY003000000008J@0026T
008000007`00Lol2000001h007?o0P00000N001co`H000005@00FKX00`00000005Vj001I^P0D001I
^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0180oooo00<0k^k^024Q8@3<c<`02P3oool000T0oooo00<000000?ooo`3o
ool00P3oool00`000000026T000QY00T000QY004000000008J@0026T0000020007?o00<00000001c
o`00Lol07@00Lol00`00000007?o001co`0S001co`H000004000FKX00`00000005Vj001I^P0D001I
^P0300000000FKX005Vj01<005Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`020?oo
o`8000005@3oool00`3<c<`08B4Q0>k^kP090?ooo`003P3oool00`000000026T000QY00R000QY003
000000008J@0026T008000007`00Lol2000001h007?o0P00000O001co`0300000000Lol007?o00T0
07?o1P00000;001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX04`00FKX00`000000
05Vj001I^P0C001I^P030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`1gMgL0
IVIV0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`020?ooo`03000000008J@0026T0240026T
00@00000000QY0008J@000008000Lol00`00000007?o001co`0M001co`0300000000Lol007?o01d0
07?o0P00000?001co`P000001P00FKX00`00000005Vj001I^P0D001I^P0300000000FKX005Vj01<0
05Vj00<00000001I^P00FKX04`00FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo00H0<S8b0>k^kP3oool0oooo038b<P2YZJT80?ooo`002@3oool00`000000oooo0?ooo`020?oo
o`03000000008J@0026T0200026T00@00000000QY0008J@000007`00Lol2000001h007?o0P00000N
001co`8000005P00Lol800000003001I^P00000005Vj01D005Vj00<00000001I^P00FKX04`00FKX0
0`00000005Vj001I^P0C001I^P040000003oool0oooo0?ooo`<000004`3oool6000000P0oooo0009
0?ooo`030000003oool0oooo0080oooo00<00000000QY0008J@07P008J@00`000000026T000QY002
000001l007?o00<00000001co`00Lol07000Lol2000001l007?o00<00000001co`00Lol06`00Lol7
000001@005Vj00<00000001I^P00FKX04`00FKX00`00000005Vj001I^P0C001I^P030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool01@0@41000000000000000000V9RH0100oooo0009
0?ooo`030000003oool0oooo0080oooo00<00000000QY0008J@07@008J@010000000026T000QY000
000O001co`8000007P00Lol00`00000007?o001co`0M001co`8000008`00Lol7000000l005Vj00<0
0000001I^P00FKX04`00FKX00`00000005Vj001I^P0C001I^P030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03@3oool00`2HV9P000000?ooo`0?0?ooo`003P3oool00`000000026T000QY00L
000QY004000000008J@00000000001l007?o00<00000001co`00Lol07000Lol2000001h007?o0P00
000P001co`0300000000Lol007?o00L007?o1`00000:001I^P0300000000FKX005Vj01@005Vj00<0
0000001I^P00FKX04P00FKX00`000000oooo0?ooo`020?ooo`800000403oool00`000000oooo0?oo
o`0>0?ooo`003P3oool00`000000026T000QY00J000QY004000000008J@0026T000001l007?o0P00
000N001co`0300000000Lol007?o01`007?o0P00000P001co`0300000000Lol007?o00h007?o1P00
0006001I^P0300000000FKX005Vj01@005Vj00<00000001I^P00FKX04P00FKX00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo1`0000040?ooo`030000003oool0oooo00h0oooo0008
0?ooo`030000003oool0oooo00<0oooo00<00000000QY0008J@06@008J@010000000026T000QY000
000O001co`0300000000Lol007?o01`007?o0P00000N001co`0300000000Lol007?o01h007?o0P00
000F001co`H0000000<005Vj00000000FKX05@00FKX00`00000005Vj001I^P0B001I^P030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`2HV9P000000?ooo`0?0?ooo`00203oool0
0`000000oooo0?ooo`030?ooo`03000000008J@0026T01P0026T00@00000000QY000000000007P00
Lol2000001h007?o00<00000001co`00Lol07000Lol2000001l007?o0P00000M001co`D000005000
FKX00`00000005Vj001I^P0B001I^P030000003oool0oooo0080oooo0P00000<0?ooo`@0000000<0
V9RH0?ooo`3oool03P3oool000P0oooo00<000000?ooo`3oool00`3oool00`000000026T000QY00E
000QY005000000008J@0026T000QY00000007`00Lol00`00000007?o001co`0L001co`8000007@00
Lol2000001l007?o0P00000N001co`8000001000Lol5000000l005Vj00<00000001I^P00FKX04P00
FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0MgMg05EEE@3oool04P3o
ool000h0oooo00<00000000QY0008J@050008J@00`000000026T000QY002000001h007?o0P00000M
001co`8000007@00Lol2000001l007?o0P00000N001co`8000002`00Lol5000000X005Vj00<00000
001I^P00FKX04`00FKX00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00@0410@
000000000000<S8b403oool000h0oooo00<00000000QY0008J@04`008J@010000000026T000QY000
000O001co`0300000000Lol007?o01`007?o00<00000001co`00Lol07000Lol00`00000007?o001c
o`0M001co`8000007P00Lol20000018007?o10000006001I^P0300000000FKX005Vj01<005Vj00<0
00000?ooo`3oool00P3oool200000200oooo00080?ooo`030000003oool0oooo00<0oooo00<00000
000QY0008J@04@008J@01@000000026T000QY0008J@0000001h007?o0P00000M001co`8000007@00
Lol2000001l007?o00<00000001co`00Lol07000Lol2000001P007?o1@0000000`00FKX00000001I
^P0D001I^P030000003oool0oooo0080oooo0P00000P0?ooo`00203oool00`000000oooo0?ooo`03
0?ooo`03000000008J@0026T0100026T00<00000000QY0008J@00P00000N001co`0300000000Lol0
07?o01`007?o00<00000001co`00Lol06`00Lol2000001l007?o0P00000N001co`0300000000Lol0
07?o01d007?o1@00000B001I^P030000003oool0oooo0080oooo0P00000P0?ooo`00203oool00`00
0000oooo0?ooo`030?ooo`03000000008J@0026T00l0026T00@00000000QY0008J@000007P00Lol2
000001d007?o0P00000M001co`0300000000Lol007?o01d007?o0P00000N001co`8000007P00Lol2
000000D007?o1@00000=001I^P030000003oool0oooo0080oooo0P00000P0?ooo`003P3oool00`00
0000026T000QY00=000QY003000000008J@0026T008000007P00Lol00`00000007?o001co`0K001c
o`8000007@00Lol2000001h007?o0P00000J001co`04000`]000Lol007?o001co`8000007P00Lol2
000000`007?o1P000007001I^P030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool0
00h0oooo00<00000000QY0008J@030008J@010000000026T000QY000000N001co`8000007@00Lol0
0`00000007?o001co`0K001co`8000007P00Lol2000001h007?o0P00000N001co`8000005000Lol5
0000008005Vj00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`00203oool00`00
0000oooo0?ooo`030?ooo`03000000008J@0026T00/0026T00@00000000QY0008J@000007P00Lol0
0`00000007?o001co`0K001co`8000007000Lol2000001h007?o0P00000N001co`8000007P00Lol2
000001/007?o100000020?ooo`<00000103oool01@2HV9P00000000000000000V9RH01L0oooo0008
0?ooo`030000003oool0oooo00<0oooo00<00000000QY0008J@02@008J@00`000000026T000QY002
000001d007?o0P00000M001co`0300000000Lol007?o01/007?o00<00000001co`00Lol00`00Lol5
000001D007?o00<00000001co`00Lol07000Lol2000001h007?o0P00000N001co`@0oooo10000004
0?ooo`050000002HV9P0oooo09RHV00000005`3oool000P0oooo00<000000?ooo`3oool00P3oool0
0`000000026T000QY009000QY004000000008J@0026T000001h007?o00<00000001co`00Lol06`00
Lol2000001`007?o0P000004001co`8000001@2^08X500000003001co`00000007?o00/007?o0P00
000M001co`8000007@00Lol3000001d007?o00<000000?ooo`3oool0103oool2000000H0oooo00D0
00000?ooo`3oool0oooo0000000G0?ooo`003@3oool00`000000026T000QY008000QY00400000000
8J@00000000001d007?o0P00000M001co`0300000000Lol007?o01X007?o0P000004001co`800000
2`2^08X6000000L007?o0P00000M001co`8000006P00Lol00`00<kH007?o001co`02000001d007?o
0P0000060?ooo`<000001`3oool01@000000oooo0?ooo`3oool0000001L0oooo000=0?ooo`030000
00008J@0026T00H0026T00@00000000QY0008J@000007P00Lol00`00000007?o001co`0K001co`80
00007000Lol00`00000007?o001co`02001co`D00000202^08X2000000H0[P2:1`00000M001co`80
00006@00Lol01000<kH007?o001co`00Lol2000001`007?o0P0000060?ooo`@000002@3oool01@00
0000oooo0?ooo`3oool0000001L0oooo00080?ooo`030000003oool0oooo0080oooo00<00000000Q
Y0008J@01@008J@010000000026T000QY000000M001co`8000007000Lol2000001`007?o0P000004
001co`800000102^08X5000000030:h0RP000000000000/0[P2:2000000H001co`0300000000Lol0
07?o01H007?o00<003>f001co`00Lol00P00Lol2000001`007?o0P0000040?ooo`060000003oool0
00000000003oool000002`3oool01@000000oooo0?ooo`3oool0000001L0oooo00080?ooo`030000
003oool0oooo0080oooo00<00000000QY0008J@010008J@010000000026T00000000000M001co`03
00000000Lol007?o01/007?o00<00000001co`00Lol06P00Lol2000000@007?o0P00000:0:h0RPH0
00001`2^08X2000000L0[P2:1P00000A001co`8000005P00Lol00`00<kH007?o001co`03001co`80
00007000Lol2000000H0oooo0`00000>0?ooo`050000002HV9P0oooo09RHV00000005`3oool000P0
oooo00<000000?ooo`3oool00P3oool010000000026T000QY0008J@200000080026T00<00000001c
o`00Lol06`00Lol2000001`007?o0P00000K001co`8000001000Lol6000000L0[P2:00<000000:h0
RP2^08X0102^08X7000000X0[P2:0P0000020:h0RPH000000P00Lol00`00000007?o001co`05001c
o`8000005@00Lol00`00<kH007?o001co`04001co`8000007000Lol2000000H0oooo0`00000@0?oo
o`0509RHV000000000000000002HV9P05`3oool000P0oooo00<000000?ooo`3oool00P3oool01000
0000026T000QY0000002000QY08000007@00Lol00`00000007?o001co`0K001co`0300000000Lol0
07?o01X007?o00<00000001co`00Lol00P00Lol3000000D0[P2:1`00000:0:h0RPL000001P2^08X0
0`000000[P2:0:h0RP070:h0RPH000000`00Lol2000001@007?o00<003>f001co`00Lol01@00Lol2
000001/007?o0`0000060?ooo`<00000;P3oool000d0oooo00<00000000QY00000000P008J@00`00
000007?o001co`0K001co`8000007000Lol2000001/007?o0P000004001co`8000002P2^08X20000
0080[P2:1P0000030:h0RP030000002^08X0[P2:00D0[P2:1P00000:0:h0RP8000000`2^08X70000
010007?o0P00<kH7001co`8000006`00Lol2000000L0oooo0`00000`0?ooo`001`3oool00`000000
oooo0?ooo`030?ooo`05000000008J@0026T000QY00000007@00Lol00`00000007?o001co`0K001c
o`0300000000Lol007?o01T007?o0P000006001co`030000002^08X0[P2:00L0[P2:0P00000:0:h0
RP<000002P2^08X2000000030:h0RP000000000000@000000`2^08X2000000X0[P2:0P00000=001c
o`8003>f2000Lol2000001/007?o0P0000060?ooo`<00000<`3oool000L0oooo00<000000?ooo`3o
ool00P3oool200000003000QY0000000000001`007?o0P00000L001co`8000006`00Lol00`000000
07?o001co`0:001co`L000002P2^08X2000000D0[P2:1`0000090:h0RPD000000`2^08X00`000000
[P2:0:h0RP020:h0RP8000003000Lol2000c]PT007?o0P00000K001co`8000001P3oool3000003D0
oooo00070?ooo`060000003oool0oooo0?ooo`000000oooo0P00000M001co`0300000000Lol007?o
01X007?o0P00000K001co`8000004P00Lol6000000@0[P2:0P00000:0:h0RPP00000102^08X20000
00@0[P2:2000000<001co`03000c]P00Lol007?o00P007?o0P00000K001co`8000001P3oool20000
03P0oooo00070?ooo`030000003oool0000000<0oooo1000000I001co`8000007000Lol00`000000
07?o001co`0I001co`8000006P00Lol6000000T0[P2:00<000000:h0RP2^08X01P2^08X5000000T0
[P2:0P00000;001co`03000c]P00Lol007?o00T007?o0P00000K001co`8000001P3oool2000003X0
oooo00080?ooo`030000003oool0oooo00H0oooo1P00000B001co`0300000000Lol007?o01X007?o
0P00000J001co`8000007@00Lol2000000<007?o1@0000020:h0RP8000002@2^08X2000000<0[P2:
1@0000030:h0RP0300000000Lol007?o00P007?o00<003>f001co`00Lol02P00Lol2000001X007?o
0`0000050?ooo`<00000?03oool000L0oooo1000000<0?ooo`H000002P00Lol2000001`007?o00<0
0000001co`00Lol06@00Lol00`00000007?o001co`0K001co`8000002P00Lol6000000D0[P2:0P00
000:0:h0RP<0000000<007?o000c]P00Lol01@00Lol2000c]P/007?o0`00000J001co`8000001P3o
ool3000000`0oooo100000000`2j^[X0oooo09RHV0030000000309RHV03oool0oooo02D0oooo000<
0?ooo`@0000000@0oooo00000000000000002@3oool6000000<007?o00<00000001co`00Lol06P00
Lol2000001X007?o0P00000L001co`8000004P00Lol6000000X0[P2:0P000007001co`8003>f3000
Lol2000001/007?o0P0000060?ooo`8000003`3oool02`3<c<`0k^k^0?ooo`3<c<`0EEEE0?ooo`00
0000V9RH0?ooo`2HV9P0000002L0oooo000D0?ooo`030000003oool00000008000002P3oool60000
01T007?o00<00000001co`00Lol06000Lol2000001`007?o0P00000J001co`D000000`2^08X20000
00H007?o0P00<kH=001co`8000006`00Lol2000000H0oooo0P00000B0?ooo`030<c<c03^k^h0oooo
0080oooo00D000000?ooo`3oool0oooo0000000W0?ooo`006@3oool00`000000oooo000000030000
00X0oooo1P00000A001co`8000006@00Lol2000001`007?o0P00000L001co`8000000`00Lol30000
00D007?o0P00<kH>001co`8000006`00Lol2000000D0oooo0`00000E0?ooo`050:VYZ@3^k^h0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`0U0?ooo`008@3oool3000000/0oooo1@00000:001c
o`8000006P00Lol00`00000007?o001co`0K001co`0300000000Lol007?o01X007?o0P00000;001c
o`03000c]P00Lol007?o00d007?o0P00000J001co`<000001P3oool3000001H0oooo00D0gMgM06IV
IP3oool0oooo000000030?ooo`030000003oool0oooo02D0oooo000V0?ooo`<000002`3oool60000
00<007?o00<00000001co`00Lol06000Lol2000001`007?o0P00000K001co`8000002P00Lol00`00
<kH007?o001co`0>001co`8000006P00Lol2000000L0oooo0`00000F0?ooo`0407MgM`3oool0oooo
00000080oooo00D000000?ooo`3oool0oooo0000000W0?ooo`00:`3oool300000080oooo0P000008
0?ooo`L000005@00Lol2000001`007?o0P00000L001co`0300000000Lol007?o00L007?o0P00<kH@
001co`8000006P00Lol2000000@0oooo00<000000?ooo`0000000`00000H0?ooo`040000002HV9P0
V9RH00000080oooo00D0000009RHV03oool0V9RH0000000W0?ooo`00<P3oool00`000000oooo0?oo
o`02000000X0oooo1`00000=001co`0300000000Lol007?o01X007?o0P00000L001co`8000001`00
Lol2000c]Q4007?o0P00000J001co`8000001P3oool4000001X0oooo00@0V9RH000000000000V9RH
0P3oool01@2HV9P00000000000000000V9RH02L0oooo000g0?ooo`030000003oool0oooo00<00000
2`3oool7000000@007?o0P00000K001co`8000007000Lol2000000H007?o0P00<kHB001co`800000
6P00Lol2000000H0oooo0`00001?0?ooo`00?`3oool3000000d0oooo1`00000H001co`8000007000
Lol2000000D007?o0P00<kHC001co`8000006@00Lol3000000H0oooo0`00001A0?ooo`00A03oool4
000000h0oooo1@00000B001co`0300000000Lol007?o01X007?o0P000004001co`8005Vn5000Lol2
000001T007?o0P0000070?ooo`800000E03oool004T0oooo10000000103oool0000000000000000:
0?ooo`H000002P00Lol2000001/007?o0P000003001co`8005Vn5@00Lol2000001T007?o0P000007
0?ooo`800000EP3oool00540oooo00<000000?ooo`0000000P00000;0?ooo`D000000`00Lol20000
01/007?o0P000003001co`8005Vn5@00Lol2000001T007?o0P0000060?ooo`<00000F03oool005H0
oooo00<000000?ooo`0000000`00000:0?ooo`<000006`00Lol20000008007?o0P00FKhE001co`<0
00006@00Lol2000000H0oooo0`00001J0?ooo`00G@3oool4000000/0oooo5P00Lol20000008007?o
00<005Vn001co`00Lol05000Lol2000001X007?o0P0000050?ooo`<00000G@3oool00680oooo1000
000;0?ooo`l007?o0P0000000`00Lol005Vn001co`0F001co`8000006@00Lol3000000H0oooo0P00
001O0?ooo`00J03oool300000080oooo0P0000070?ooo`P007?o0P00000I001co`8000006@00Lol2
000000H0oooo0`00000>0?ooo`0509RHV000000000000000002HV9P0CP3oool006l0oooo00<00000
0?ooo`3oool00P0000070?ooo`8007?o1@00000E001co`8000006@00Lol2000000H0oooo0`00000@
0?ooo`050000002HV9P0oooo09RHV0000000CP3oool007@0oooo00<000000?ooo`3oool00P000009
0?ooo`L000003000Lol2000001T007?o0P0000060?ooo`8000004`3oool01@000000oooo0?ooo`3o
ool0000004h0oooo001i0?ooo`030000003oool0oooo00<000002P3oool7000000<007?o0P00000I
001co`8000001P3oool4000001<0oooo00D000000?ooo`3oool0oooo0000001>0?ooo`00P@3oool3
000000`0oooo1P00000E001co`<000000`3oool00`000000oooo0?ooo`04000001D0oooo00D00000
0?ooo`3oool0oooo0000001>0?ooo`00QP3oool4000000040?ooo`0000000000000000P0oooo1`00
000<001co`8000001P3oool4000001P0oooo00D000000?ooo`3oool0oooo0000001>0?ooo`00SP3o
ool00`000000oooo00000002000000X0oooo1`000003001co`8000001`3oool3000001X0oooo00D0
000009RHV03oool0V9RH0000001>0?ooo`00T`3oool00`000000oooo00000002000000`0oooo0`00
00060?ooo`<000007@3oool01@2HV9P00000000000000000V9RH04h0oooo002H0?ooo`030000003o
ool0000000<000002P3oool00`000000oooo0000000300000780oooo002O0?ooo`@000001@3oool4
000007@0oooo002T0?ooo`H00000MP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00:l0oooo100000000`2j^[X0oooo09RHV0030000000309RHV03oool0oooo06@0oooo002_0?oo
o`0;0<c<c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000IP3oool00;00oooo
00<0c<c<0>k^kP3oool00P3oool01@000000oooo0?ooo`3oool000000140oooo0`0000000`3oool0
MgMg00000002000004d0oooo002X0?ooo`L000000P3oool01@2YZJT0k^k^0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0403oool01P2HV9P0MgMg0?ooo`3oool08B4Q0:VYZDh0oooo002a0?oo
o`050=gMg@1VIVH0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0A0?ooo`0405EEE@2HV9P0
MgMg06IVITl0oooo002_0?ooo`0407MgM`3oool0oooo00000080oooo00D000000?ooo`3oool0oooo
0000000C0?ooo`030>k^kP0Q8B40<S8b0500oooo002_0?ooo`040000002HV9P0V9RH00000080oooo
00D0000009RHV03oool0V9RH0000000C0?ooo`030>k^kP0@4100<S8b0500oooo002_0?ooo`0409RH
V0000000000009RHV080oooo00D0V9RH000000000000000009RHV00C0?ooo`0406IVIP1gMgL0ZJVY
06IVITl0oooo003<0?ooo`040:VYZ@0Q8B40oooo0?ooo`80V9RH00<0k^k^0?ooo`3oool0B`3oool0
0</0oooo0`0000000`1gMgL0oooo038b<P02000000030;Zj^P3oool0oooo04X0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.30085*^-6, -0.0579078, \
0.00388786, 0.00388786}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot the field signature of the shim", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x = 5;\)\ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ position\ *) \), "\[IndentingNewLine]", 
    \(\(z = 10;\)\ \ \ \ \ \ \ \  (*\ 
      Vertical\ position\ above\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(npt = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Plot[radFld[shim, "\<Bz\>", {x, y, z}], {y, \(-per\), per}, 
        PlotLabel \[Rule] "\< Vertical Field [T] produced by the shim at \
(x,z)=(5,10) mm vs longitudinal position [mm]\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0136054 0.352535 473.797 [
[.09184 -0.0125 -12.125 -14 ]
[.09184 -0.0125 12.125 0 ]
[.22789 -0.0125 -12.125 -14 ]
[.22789 -0.0125 12.125 0 ]
[.36395 -0.0125 -12.125 -14 ]
[.36395 -0.0125 12.125 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.63605 -0.0125 -8 -14 ]
[.63605 -0.0125 8 0 ]
[.77211 -0.0125 -8 -14 ]
[.77211 -0.0125 8 0 ]
[.90816 -0.0125 -8 -14 ]
[.90816 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06826 -45.25 -7 ]
[-0.0125 .06826 0 7 ]
[-0.0125 .16302 -45.25 -7 ]
[-0.0125 .16302 0 7 ]
[-0.0125 .25778 -45.25 -7 ]
[-0.0125 .25778 0 7 ]
[-0.0125 .35254 -10 -7 ]
[-0.0125 .35254 0 7 ]
[-0.0125 .44729 -37 -7 ]
[-0.0125 .44729 0 7 ]
[-0.0125 .54205 -37 -7 ]
[-0.0125 .54205 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -218.875 0 ]
[.5 .63053 218.875 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
gsave
.09184 -0.0125 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.22789 0 m
.22789 .00625 L
s
gsave
.22789 -0.0125 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.36395 0 m
.36395 .00625 L
s
gsave
.36395 -0.0125 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.63605 0 m
.63605 .00625 L
s
gsave
.63605 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.77211 0 m
.77211 .00625 L
s
gsave
.77211 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.90816 0 m
.90816 .00625 L
s
gsave
.90816 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06826 m
.00625 .06826 L
s
gsave
-0.0125 .06826 -106.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0006) show
1.000 setlinewidth
grestore
0 .16302 m
.00625 .16302 L
s
gsave
-0.0125 .16302 -106.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0004) show
1.000 setlinewidth
grestore
0 .25778 m
.00625 .25778 L
s
gsave
-0.0125 .25778 -106.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0002) show
1.000 setlinewidth
grestore
0 .35254 m
.00625 .35254 L
s
gsave
-0.0125 .35254 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .44729 m
.00625 .44729 L
s
gsave
-0.0125 .44729 -98 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0002) show
1.000 setlinewidth
grestore
0 .54205 m
.00625 .54205 L
s
gsave
-0.0125 .54205 -98 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0004) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09195 m
.00375 .09195 L
s
0 .11564 m
.00375 .11564 L
s
0 .13933 m
.00375 .13933 L
s
0 .18671 m
.00375 .18671 L
s
0 .2104 m
.00375 .2104 L
s
0 .23409 m
.00375 .23409 L
s
0 .28147 m
.00375 .28147 L
s
0 .30516 m
.00375 .30516 L
s
0 .32885 m
.00375 .32885 L
s
0 .37623 m
.00375 .37623 L
s
0 .39992 m
.00375 .39992 L
s
0 .4236 m
.00375 .4236 L
s
0 .47098 m
.00375 .47098 L
s
0 .49467 m
.00375 .49467 L
s
0 .51836 m
.00375 .51836 L
s
0 .04457 m
.00375 .04457 L
s
0 .02088 m
.00375 .02088 L
s
0 .56574 m
.00375 .56574 L
s
0 .58943 m
.00375 .58943 L
s
0 .61312 m
.00375 .61312 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09184 .61178 m
.09184 .61803 L
s
.22789 .61178 m
.22789 .61803 L
s
.36395 .61178 m
.36395 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63605 .61178 m
.63605 .61803 L
s
.77211 .61178 m
.77211 .61803 L
s
.90816 .61178 m
.90816 .61803 L
s
.125 Mabswid
.11905 .61428 m
.11905 .61803 L
s
.14626 .61428 m
.14626 .61803 L
s
.17347 .61428 m
.17347 .61803 L
s
.20068 .61428 m
.20068 .61803 L
s
.2551 .61428 m
.2551 .61803 L
s
.28231 .61428 m
.28231 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.33673 .61428 m
.33673 .61803 L
s
.39116 .61428 m
.39116 .61803 L
s
.41837 .61428 m
.41837 .61803 L
s
.44558 .61428 m
.44558 .61803 L
s
.47279 .61428 m
.47279 .61803 L
s
.52721 .61428 m
.52721 .61803 L
s
.55442 .61428 m
.55442 .61803 L
s
.58163 .61428 m
.58163 .61803 L
s
.60884 .61428 m
.60884 .61803 L
s
.66327 .61428 m
.66327 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.71769 .61428 m
.71769 .61803 L
s
.7449 .61428 m
.7449 .61803 L
s
.79932 .61428 m
.79932 .61803 L
s
.82653 .61428 m
.82653 .61803 L
s
.85374 .61428 m
.85374 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.06463 .61428 m
.06463 .61803 L
s
.03741 .61428 m
.03741 .61803 L
s
.0102 .61428 m
.0102 .61803 L
s
.93537 .61428 m
.93537 .61803 L
s
.96259 .61428 m
.96259 .61803 L
s
.9898 .61428 m
.9898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06826 m
1 .06826 L
s
.99375 .16302 m
1 .16302 L
s
.99375 .25778 m
1 .25778 L
s
.99375 .35254 m
1 .35254 L
s
.99375 .44729 m
1 .44729 L
s
.99375 .54205 m
1 .54205 L
s
.125 Mabswid
.99625 .09195 m
1 .09195 L
s
.99625 .11564 m
1 .11564 L
s
.99625 .13933 m
1 .13933 L
s
.99625 .18671 m
1 .18671 L
s
.99625 .2104 m
1 .2104 L
s
.99625 .23409 m
1 .23409 L
s
.99625 .28147 m
1 .28147 L
s
.99625 .30516 m
1 .30516 L
s
.99625 .32885 m
1 .32885 L
s
.99625 .37623 m
1 .37623 L
s
.99625 .39992 m
1 .39992 L
s
.99625 .4236 m
1 .4236 L
s
.99625 .47098 m
1 .47098 L
s
.99625 .49467 m
1 .49467 L
s
.99625 .51836 m
1 .51836 L
s
.99625 .04457 m
1 .04457 L
s
.99625 .02088 m
1 .02088 L
s
.99625 .56574 m
1 .56574 L
s
.99625 .58943 m
1 .58943 L
s
.99625 .61312 m
1 .61312 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .35254 m
1 .35254 L
s
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -279.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vertical) show
107.438 14.000 moveto
(Field) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 14.000 moveto
(@) show
138.938 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.250 14.000 moveto
(D) show
153.188 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(produced) show
200.812 14.000 moveto
(by) show
215.812 14.000 moveto
(the) show
233.438 14.000 moveto
(shim) show
259.688 14.000 moveto
(at) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
271.312 14.000 moveto
(H) show
275.125 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
281.125 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
284.125 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
289.438 14.000 moveto
(L) show
293.250 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
300.938 14.000 moveto
(H) show
304.750 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
310.750 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
313.750 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
325.750 14.000 moveto
(L) show
332.562 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
354.188 14.000 moveto
(vs) show
367.812 14.000 moveto
(longitudinal) show
428.688 14.000 moveto
(position) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
470.250 14.000 moveto
(@) show
474.188 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.812 14.000 moveto
(D) show
496.750 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .36022 m
.06244 .36191 L
.10458 .36425 L
.14415 .36699 L
.18221 .37017 L
.22272 .37401 L
.26171 .37771 L
.28158 .3793 L
.29205 .37998 L
.29779 .38029 L
.30316 .38054 L
.30831 .38074 L
.31304 .38088 L
.31828 .381 L
.32117 .38105 L
.32392 .38108 L
.32622 .3811 L
.3275 .38111 L
.32867 .38112 L
.32976 .38112 L
.33094 .38113 L
.33206 .38113 L
.33308 .38113 L
.33428 .38113 L
.3354 .38112 L
.33663 .38112 L
.33795 .38112 L
.34309 .38109 L
.34565 .38108 L
.34705 .38107 L
.34837 .38106 L
.34949 .38106 L
.35069 .38106 L
.35135 .38106 L
.35203 .38106 L
.35326 .38106 L
.35395 .38106 L
.35458 .38106 L
.35531 .38107 L
.356 .38107 L
.35722 .38108 L
.35854 .3811 L
.36 .38112 L
.36155 .38116 L
.36433 .38124 L
.36671 .38134 L
.36928 .38147 L
.3717 .38164 L
.37391 .38183 L
.37649 .38211 L
Mistroke
.37931 .38248 L
.38445 .38337 L
.38978 .38468 L
.39479 .38633 L
.39929 .38823 L
.40416 .3908 L
.40948 .39433 L
.41509 .39897 L
.42514 .40997 L
.43465 .42397 L
.44482 .44303 L
.46317 .4868 L
.48302 .5401 L
.49348 .56557 L
.49921 .57749 L
.50458 .58693 L
.50933 .59365 L
.51177 .59646 L
.51444 .599 L
.51721 .60103 L
.51872 .60187 L
.52012 .60249 L
.52144 .60291 L
.52264 .60317 L
.5233 .60326 L
.52402 .60332 L
.52532 .60331 L
.52651 .60318 L
.52763 .60294 L
.52885 .60256 L
.53017 .60201 L
.53285 .60043 L
.53529 .59847 L
.54001 .59329 L
.54448 .58673 L
.55412 .56755 L
.56436 .54041 L
.58278 .47795 L
.62049 .31842 L
.64144 .22479 L
.66067 .14471 L
.67949 .07964 L
.68896 .05432 L
.69428 .04267 L
.69932 .03349 L
.70424 .02628 L
.70683 .02318 L
.70958 .02044 L
.71189 .01856 L
.71443 .01692 L
Mistroke
.71554 .01635 L
.71674 .01583 L
.71779 .01546 L
.71891 .01515 L
.71964 .01499 L
.7203 .01488 L
.72159 .01474 L
.72231 .01472 L
.7231 .01472 L
.72384 .01477 L
.72452 .01484 L
.72575 .01505 L
.72645 .01521 L
.72711 .01539 L
.72985 .01642 L
.73237 .01777 L
.73467 .01931 L
.73985 .0238 L
.74977 .03591 L
.75895 .05034 L
.77971 .0898 L
.819 .16747 L
.85677 .22678 L
.87613 .24994 L
.89699 .2701 L
.91666 .2853 L
.93815 .2985 L
.97619 .31533 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{503.062, 310.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007g0001=R000`400?l00000o`00003oo`3ooooh
0?ooo`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00G`3oool0
100@41000000010@401gMgL20?ooo`0509RHV000000000000000002HV9P0<@3oool4000000030;Zj
^P3oool0V9RH00<0000000<0V9RH0?ooo`3oool0<03oool3000000030?ooo`2HV9P0000000800000
00<0V9RH0?ooo`3oool0;P3oool01@2HV9P00000000000000000V9RH03D0oooo0`0000000`3oool0
V9RH000000020000000309RHV03oool0oooo02l0oooo100000000`2j^[X0oooo09RHV00300000003
09RHV03oool0oooo02l0oooo00@0410@0000000@4100MgMg0P3oool01@2HV9P00000000000000000
V9RH02/0oooo001R0?ooo`0807MgM`1VIVH0oooo0000002HV9P0oooo09RHV000000a0?ooo`0;0<c<
c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000<`3oool020000000oooo0?oo
o`000000V9RH0?ooo`2HV9P00000<03oool01@000000V9RH0?ooo`2HV9P0000003H0oooo00P00000
0?ooo`3oool0000009RHV03oool0V9RH00000340oooo00/0c<c<0>k^kP3oool0c<c<05EEE@3oool0
000009RHV03oool0V9RH0000000d0?ooo`0807MgM`1VIVH0oooo0000002HV9P0oooo09RHV000000[
0?ooo`00H`3oool00`000000oooo000000030?ooo`030000003oool0oooo0300oooo00<0c<c<0>k^
kP3oool00P3oool01@000000oooo0?ooo`3oool0000003<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000=P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0300oooo00<0c<c<0>k^kP3oool00P3oool01@000000
oooo0?ooo`3oool0000003D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0Y0?oo
o`00F03oool700000080oooo00D0gMgM08N7Q`000000oooo000000030?ooo`030000003oool0oooo
02L0oooo1`0000030?ooo`050:VYZ@3^k^h0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0W
0?ooo`L000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02h0oooo00D0
00000?ooo`3oool0oooo0000000f0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0<@3oool01@2YZJT0k^k^0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0<@3oool01@3M
gMd0QhN70000003oool0000000<0oooo00<000000?ooo`3oool0:@3oool00600oooo00H0EEEE010@
40000000V9RH0?ooo`0000030?ooo`030000003oool0oooo0340oooo00D0gMgM06IVIP3oool0oooo
000000030?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000=P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0340oooo00D0gMgM06IVIP3oool0oooo000000030?ooo`030000003o
ool0oooo0300oooo00H0EEEE010@40000000V9RH0?ooo`0000030?ooo`030000003oool0oooo02T0
oooo001R0?ooo`040;Zj^P2HV9P0oooo000000<0oooo00<000000?ooo`3oool0;`3oool0101gMgL0
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000<`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0;`3oool0101gMgL0oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`000000=03oool0102j^[X0V9RH0?ooo`0000030?ooo`030000003o
ool0oooo02T0oooo001O0?ooo`0;04A4A02j^[X0oooo0;Zj^P000000oooo0000002HV9P0oooo09RH
V0000000<@3oool010000000V9RH09RHV00000020?ooo`050000002HV9P0oooo09RHV0000000<`3o
ool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000<03oool01@000000V9RH0?ooo`2HV9P0
000003H0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH00000340oooo00@0000009RHV02H
V9P000000P3oool01@000000V9RH0?ooo`2HV9P000000340oooo00/0A4A40;Zj^P3oool0^[Zj0000
003oool0000009RHV03oool0V9RH0000000[0?ooo`00G`3oool01`3^k^h0A4A4000000000000V9RH
0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0_0?ooo`0409RHV0000000000009RHV080oooo00D0
V9RH000000000000000009RHV00b0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0
oooo0?ooo`0^0?ooo`0509RHV000000000000000002HV9P0=@3oool01@0Q8B4000000?ooo`3oool0
V9RH00<0000000<0V9RH0?ooo`3oool0;`3oool0102HV9P000000000002HV9P20?ooo`0509RHV000
000000000000002HV9P0<@3oool01`3^k^h0A4A4000000000000V9RH0?ooo`2HV9P00`0000000`2H
V9P0oooo0?ooo`0Y0?ooo`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00o`3ooooh
0?ooo`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00>@3ooooo00000;P000001`3oool003T0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool01@000000oooo0?ooo`3oool0000000L0oooo000i0?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`00>@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`3oool0f03oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0oooo05h0oooo0P00001h0?ooo`030000003oool0oooo00D0oooo000i0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0F`3oool8000007D0oooo00<000000?oo
o`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`050?ooo`00
>@3oool200000=T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`080?ooo`800000
L03oool3000000L0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool01@3o
ool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00D0oooo000i
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?oo
o`3oool0f03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
1@3oool003T0oooo0P00003I0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`1W0?ooo`<000001`3oool003T0oooo00<000000?ooo`3oool0f03oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01@3oool003T0oooo
00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?oo
o`3H0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?oo
o`00403oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`0000000`2H
V9P0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2H
V9P0oooo0?ooo`070?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool00100
oooo00D0000009RHV03oool0V9RH000000040?ooo`0G0000002HV9P0oooo09RHV0000000oooo0000
002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RH
V00000002@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo000@0?ooo`05
0000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3o
ool300000=P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0600oooo100000070?ooo`002@3oool8000000<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`070000
003oool000000<c<c03oool0V9RH000000090?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool01@3oool00100oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`0@4100EEEE
0P0000000`2HV9P0oooo0?ooo`070?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
1@3oool00100oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`1gMgL0A4A4303oool0
0`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo000@0?ooo`050000002HV9P0oooo
09RHV0000000103oool04@000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P000000080oooo00<0EEEE07MgM`3oool02P3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo000@0?ooo`0509RHV000000000000000002HV9P0
103oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000
000709RHV03oool0oooo0?ooo`2HV9P0A4A408N7Q`090?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`05
0?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00D0oooo000i0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`050?ooo`00>@3oool200000=T0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05`0oooo0`0000070?ooo`00>@3oool0
0`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00D0oooo
000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool01@3oool003T0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`050?ooo`00>@3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00D0oooo000i0?ooo`800000f@3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0EP3oool3
000000L0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool01@3oool003T0
oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`05
0?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00D0oooo000i0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo00D0oooo000i0?ooo`800000f@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0D@3oool3000000L0oooo000i0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00D0oooo
000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool01@3oool003T0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`00403o
ool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`0000000`2HV9P0oooo
09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00100oooo00D0
000009RHV03oool0V9RH000000040?ooo`0A0000002HV9P0oooo09RHV0000000oooo0000002HV9P0
oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool01@3oool00100oooo00D000000?ooo`3o
ool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001@0000080?ooo`<00000f03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0BP3oool4000000L0oooo0009
0?ooo`P000000`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0000000<0oooo00H000000?ooo`14A4@0V9RH0?ooo`00000:0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool00100oooo00D000000?ooo`3o
ool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0000000<0oooo00H000000?ooo`3^k^h0410@0=gMg@00000:0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool01@3oool00100oooo00D000000?ooo`3oool0oooo000000040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00H00000
0?ooo`3oool0ZJVY038b<P00000:0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
1@3oool00100oooo00D0000009RHV03oool0V9RH000000040?ooo`0A0000002HV9P0oooo09RHV000
0000oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV00000000`3oool00`1V
IVH000000?ooo`090?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool01@3oool00100
oooo00D0V9RH000000000000000009RHV0040?ooo`0709RHV000000000000000002HV9P0oooo09RH
V0030000000309RHV03oool0V9RH00<0000000H0V9RH0?ooo`3oool0oooo0>k^kP0@410:0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01@3oool0
03T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?ooo`00>@3oool200000=T0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04D0
oooo0`0000070?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00D0oooo
000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool01@3oool003T0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`00>@3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0
oooo0=P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`050?ooo`00>@3oool200000=T0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo03l0oooo0`0000070?ooo`00>@3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`05
0?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo000i0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool01@3oool0
03T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000
oooo0?ooo`3H0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo000i0?ooo`800000f@3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0=`3oool3000000L0oooo
000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3oool003T0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`00>@3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0
oooo0=P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1V0?ooo`800000=03oool0
0`000000oooo0?ooo`050?ooo`00403oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b
0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH
0?ooo`0000000`0000000`2j^[X0oooo0?ooo`070?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool01@3oool00100oooo00D0000009RHV03oool0V9RH000000040?ooo`0G0000002HV9P0
oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000
oooo0<c<c03^k^h0oooo0<c<c01EEED02@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00D0oooo000@0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`050000003oool0oooo0<c<c03^
k^h02`3oool300000=P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo02`0oooo100000070?ooo`002@3oool8000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`060000003oool0oooo0?ooo`2YZJT0k^k^2P3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00D0oooo000@0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`060000003oool0oooo0?oo
o`3MgMd0IVIV2P3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo000@0?oo
o`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo000000030?ooo`030000003oool0MgMg0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo000@0?ooo`050000002H
V9P0oooo09RHV0000000103oool04`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2H
V9P000000?ooo`000000V9RH0?ooo`2HV9P000000?ooo`0000000P2HV9P00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00100oooo00D0V9RH0000
00000000000009RHV0040?ooo`0709RHV000000000000000002HV9P0oooo09RHV0030000000309RH
V03oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00P0000000`2HV9P0oooo0?ooo`080?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1a0?ooo`800000
:`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01@3oool0
03T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
07H0oooo0P00000W0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool01@3oool003T0oooo0P00003I0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`<000001`3oool003T0oooo00<0
00000?ooo`3oool0f03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0O03oool200000280oooo00<00000
0?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?oo
o`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0O`3oool2000001l0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0
f03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0PP3oool2000001`0oooo00<000000?ooo`3oool01@3o
ool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool20000
01T0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo08P0oooo0`00000F0?ooo`030000003oool0oooo00D0
oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`2;0?ooo`800000503oool00`000000oooo0?ooo`050?ooo`00>@3oool200000=T0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`2>0?ooo`<000003`3oool3000000L0oooo000i
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2A
0?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0T`3oool2000000d0oooo00<000000?oo
o`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo09D0oooo0`00000:0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2H0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool01@3o
ool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool01@3oool003T0
oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool01@3oool003T0oooo0P00
003I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0XP3oool3000000L0oooo000i
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00D0oooo000i0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo00D0oooo000[0?ooo`0509RHV000000000000000002H
V9P02@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`050?ooo`00:`3oool01@000000V9RH0?ooo`2HV9P0000000T0
oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool01@3oool002/0oooo00D000000?ooo`3oool0oooo000000090?ooool0
0000^00000070?ooo`00:`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0f03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool002/0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0
oooo000[0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`070?ooo`X0
0000a`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool002/0oooo00D0000009RHV03oool0V9RH000000090?ooo`030000003oool0oooo0140
oooo4@00002f0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`050?ooo`00:`3oool01@2HV9P00000000000000000V9RH00T0oooo00<000000?ooo`3o
ool08P3ooolB00000:@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo03@0oooo4P00002B0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`050?ooo`00>@3o
ool00`000000oooo0?ooo`160?ooo``00000QP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0DP3oool9
000007d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo00D0oooo000i0?ooo`030000003oool0oooo05/0oooo2000001e0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`050?ooo`00>@3oool2000006@0
oooo2@00001/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0Y`3oool3000000L0
oooo000i0?ooo`030000003oool0oooo06`0oooo4000001L0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?oo
o`1l0?ooobH00000=P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:T0oooo00<0
00000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0XP3oool600000300oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00D0oooo000i0?oo
o`030000003oool0oooo0:P0oooo1000000/0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`2/0?ooo`80
0000:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3o
ool01@3oool003T0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`050?ooo`00>@3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0
oooo0;00oooo0P00000V0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
00D0oooo000i0?ooo`800000]03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0Z@3oool3000000L0oooo000i0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`050?ooo`00>@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00D0oooo000i0?oo
o`030000003oool0oooo0;H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0:`0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`2g0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool01@3o
ool003T0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`00
0000oooo0?ooo`2i0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0;X0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool01@3oool003T0oooo0P00002l0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2/0?ooo`<000001`3oool003T0oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool01@3oool003T0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`050?ooo`00
>@3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`050?ooo`00403oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b
0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0V9RH00<0000000<0V9RH
0?ooo`0000000`0000000`2j^[X0oooo0?ooo`070?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool01@3oool00100oooo00D0000009RHV03oool0V9RH000000040?ooo`0G0000002HV9P0
oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000
oooo0<c<c03^k^h0oooo0<c<c01EEED02@3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo00D0oooo000@0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`050000003oool0oooo0<c<c03^
k^h02`3oool300000<40oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0:d0oooo100000070?ooo`00403oool01@000000oooo0?ooo`3oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool0
1P000000oooo0?ooo`3oool0ZJVY0>k^kPX0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`050?ooo`00403oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`3oool0
gMgM06IVIPX0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`050?ooo`00403oool0
1@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo07MgM`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`050?ooo`00403oool01@000000V9RH
0?ooo`2HV9P0000000@0oooo01<0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH
0000003oool0000009RHV03oool0V9RH0000003oool000000080V9RH00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo00D0oooo000@0?ooo`0509RHV0000000
00000000002HV9P0103oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00`0000000`2HV9P0
oooo09RHV0030000000309RHV03oool0V9RH0080000000<0V9RH0?ooo`3oool0203oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`050?ooo`00>@3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00D0oooo000i0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0;<0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`050?ooo`00>@3oool200000<H0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;40oooo0`0000070?ooo`00>@3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo00D0
oooo000i0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool01@3oool003T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`38
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool01@3oool003T0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`050?ooo`00
>@3oool200000<X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0;@0oooo0`0000070?ooo`00>@3oool00`000000oooo0?ooo`3:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo00D0oooo000i0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool01@3oool0
03T0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000
oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;L0oooo
00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?oo
o`050?ooo`00>@3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo00D0oooo000i0?oo
o`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0;P0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3o
ool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0^@3oool00`000000oooo0?ooo`050?ooo`00>@3oool200000<h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;L0oooo0`0000070?ooo`00>@3o
ool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0
oooo0<d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00D0
oooo000i0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool01@3oool003T0oooo00<0
00000?ooo`3oool0c`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2k
0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool01@3oool00100oooo00D0V9RH000000000000000009RHV0020?ooo`03038b<P3oool0V9RH
00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo
00D0oooo000@0?ooo`050000002HV9P0oooo09RHV0000000103oool04@000000V9RH0?ooo`2HV9P0
00000?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000000@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00D0oooo000@
0?ooo`050000003oool0oooo0?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo000000030?ooo`030000003oool0000000D00000203oool300000=00
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0;T0
oooo100000070?ooo`00403oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool01P000000oooo04A4A02H
V9P0oooo000000X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`00403o
ool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`0000000`3oool01P000000oooo0>k^kP0@4100gMgM000000X0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0_@3oool00`000000oooo0?ooo`050?ooo`00403oool01@000000oooo0?ooo`3o
ool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
00000`3oool01P000000oooo0?ooo`2YZJT0<S8b000000X0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`050?ooo`00403oool01@000000V9RH0?ooo`2HV9P0000000@0oooo01400000
09RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH0000003oool0000009RHV03oool0V9RH
000000030?ooo`0306IVIP000000oooo00T0oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0_P3oool00`000000oooo
0?ooo`050?ooo`00403oool01@2HV9P00000000000000000V9RH00@0oooo00L0V9RH000000000000
000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000001P2HV9P0oooo0?ooo`3oool0
k^k^010@40X0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`00>@3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0;l0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0e03oool01@000000
oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`050?oo
o`00>@3oool00`000000oooo0?ooo`3D0?ooo`050000003oool0oooo0?ooo`000000603oool00`00
0000oooo0?ooo`2o0?ooo`030000003oool0oooo00D0oooo000i0?ooo`800000eP3oool010000000
oooo0?ooo`00000G0?ooo`030000003oool0oooo0;h0oooo0`0000070?ooo`00>@3oool00`000000
oooo0?ooo`3E0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool0`03oool00`00
0000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0000001L0
oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo
0?ooo`3F0?ooo`030000003oool0000001H0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0000001D0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3G
0?ooo`8000005@3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo00D0oooo000i0?oo
o`030000003oool0oooo0=L0oooo0P00000D0?ooo`030000003oool0oooo0<<0oooo00<000000?oo
o`3oool01@3oool003T0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0<<0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool0
f03oool200000180oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`050?ooo`00>@3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool000000100oooo00<000000?ooo`3oool0a@3o
ool00`000000oooo0?ooo`050?ooo`00>@3oool200000=T0oooo00<000000?ooo`000000403oool0
0`000000oooo0?ooo`330?ooo`<000001`3oool003T0oooo00<000000?ooo`3oool0f03oool01000
0000oooo0?ooo`00000>0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool01@3oool0
03T0oooo00<000000?ooo`3oool0f03oool01@000000oooo0?ooo`3oool0000000`0oooo00<00000
0?ooo`3oool0a`3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`380?ooo`030000003oool0
oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool01@3oool003T0
oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`800000c@3oool00`000000oooo
0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo00L0oooo0P00
003?0?ooo`030000003oool0oooo00D0oooo000i0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`050?ooo`00>@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo000i0?ooo`800000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo00000002000000L0oooo000i0?ooo`050000003oool0oooo0?ooo`000000
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000070?ooo`00>@3ooooo00000;P000001`3oool00?l0oooon03oool00?l0oooon03oool0
0?l0oooon03oool00?l0oooon03oool00?l0oooon03oool00?l0oooon03oool009D0oooo0`00000c
0?ooo`03010@40000000c<c<0:d0oooo00H0V9RH010@40000000410@07MgM`3^k^hX0?ooo`<00000
B`3oool008<0oooo0`0000090?ooo`<00000103oool00`000000oooo0?ooo`0c0?ooo`030>k^kP0Q
8B40oooo03h0oooo00<0k^k^09RHV03oool01@3oool00`3<c<`0oooo0?ooo`050?ooo`030;Zj^P3<
c<`0oooo00/0oooo00<0k^k^09RHV03oool01@3oool00`3<c<`0oooo0?ooo`0<0?ooo`030;Zj^P3<
c<`0oooo03H0oooo00H000000;Zj^P3oool0k^k^08N7Q`0b<S8Y0?ooo`030000003oool0oooo02D0
oooo0`00000E0?ooo`<000002P3oool008<0oooo00<000000>k^kP3oool02P3oool00`3^k^h00000
0?ooo`030?ooo`030000003oool0oooo03@0oooo00<0IVIV09RHV03oool0?03oool00`3^k^h0IVIV
0?ooo`060?ooo`03010@403oool0oooo00H0oooo00<0EEEE0=gMg@3oool02@3oool00`3^k^h0IVIV
0?ooo`060?ooo`03010@403oool0oooo00d0oooo00<0EEEE0=gMg@3oool0=@3oool01P1gMgL0k^k^
0?ooo`3oool0gMgM000002T0oooo00<000000?ooo`3oool09@3oool00`000000k^k^0?ooo`0F0?oo
o`030>k^kP000000oooo00T0oooo00110?ooo`030=gMg@000000c<c<0080oooo00D0V9RH0000000@
4100c<c<0?ooo`0300000080oooo00<0ZJVY038b<P0000000P0000002P2HV9P00000010@403<c<`0
oooo09RHV0000000V9RH024Q8@1EEED3000000D0oooo0`0000040?ooo`<0000000D0V9RH0000000@
4100c<c<0?ooo`030000000409RHV0000000000007MgM`800000103oool00`000000oooo0?ooo`03
0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`0500000014A4@0000009RHV03oool00`00
00000`3oool0V9RH000000020000000309RHV03oool0V9RH0080000000L0MgMg000000000000oooo
09RHV0000000V9RH0080000000/0V9RH0000000@4100c<c<0?ooo`2HV9P00000010@403<c<`0oooo
09RHV0020000000307MgM`000000000000D0oooo00@0<S8b000000000000V9RH0`3oool00`2HV9P0
8B4Q0?ooo`050?ooo`030:VYZ@0b<S8000000080000000L0oooo000000000000V9RH0000000@4100
c<c<00@0oooo00D0000005EEE@000000V9RH0?ooo`03000000030?ooo`000000000000H0000000@0
oooo000000000000oooo0P0000040?ooo`0809RHV0000000V9RH024Q8@1EEED0oooo0:VYZ@0b<S84
0?ooo`0307MgM`2YZJT0oooo0080000000D0^[Zj07MgM`0000000000010@40020?ooo`D0000000<0
oooo0<c<c01EEED02P3oool0101gMgL0ZJVY0?ooo`0@41030000000309RHV03oool0410@00@0oooo
0`0000000`3oool0V9RH000000020000000509RHV03oool0oooo0<c<c01EEED0103oool300000004
0?ooo`00000000000?ooo`D0000000@0oooo000000000000oooo0P0000040?ooo`080=gMg@000000
gMgM0?ooo`000000EEEE0000002HV9P50?ooo`<0000000H0V9RH000000000000000009RHV03oool3
000000040?ooo`000000000007MgM`<0000000<0410@08N7Q`0000000P0000001`3oool0ZJVY038b
<P3oool0V9RH0000002HV9P00P000000102HV9P000000000001gMgL8000000080?ooo`0000000000
09RHV0000000V9RH024Q8@1EEED3000000H0oooo00H0000004A4A0000000V9RH0?ooo`2HV9P30000
000709RHV03oool0000005EEE@000000V9RH0?ooo`03000000030?ooo`2YZJT0<S8b00<0000000H0
V9RH000000000000000009RHV03oool3000000030?ooo`000000000000<0oooo00@000000?ooo`3o
ool0oooo0`000000103oool000000000003oool5000000040?ooo`00000000000?ooo`800000103o
ool00`000000oooo0?ooo`080?ooo`00@@3oool00`1VIVH0410@06IVIP020?ooo`040000002HV9P0
^[Zj010@4080oooo00D000000?ooo`3oool0oooo000000020?ooo`0>0000003oool0000009RHV02j
^[X0<S8b0?ooo`000000V9RH0=gMg@000000k^k^0?ooo`0000070?ooo`030000003oool0oooo00@0
oooo00H000000?ooo`000000V9RH0;Zj^P0@41020?ooo`070000003oool0000009RHV03oool0c<c<
000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`040000003<c<`0V9RH00000080oooo00h000000?ooo`3oool0000009RHV03oool0
V9RH0000003oool0000009RHV03oool0c<c<00000080oooo01@0000009RHV03<c<`000000?ooo`00
0000V9RH0;Zj^P0b<S80oooo0000002HV9P0^[Zj010@403oool0000009RHV03oool0c<c<000000H0
oooo00@000000>k^kP2HV9P000000`3oool00`0b<S8000000<c<c0050?ooo`040000003oool0oooo
00000080oooo00H000000?ooo`000000V9RH0;Zj^P0@41040?ooo`04024Q8@3^k^h0V9RH00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000D0oooo00L0000009RHV03MgMd000000>k^kP3oool0000000D0oooo00T08B4Q0=gMg@3o
ool0c<c<024Q8@3<c<`0ZJVY024Q8@3^k^h00`3oool01@3<c<`08B4Q0?ooo`3oool0<S8b0080oooo
00<000000?ooo`3oool01`0000000`3oool08B4Q0=gMg@040?ooo`0309RHV0000000oooo00H0oooo
00P000000?ooo`3oool0000009RHV03oool0V9RH000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001@3oool02027QhL0000008N7Q`3oool08B4Q0>k^kP2HV9P000001P3oool01`000000oooo0000
002HV9P0oooo09RHV00000000P3oool01`000000oooo0?ooo`000000oooo038b<P3MgMd01@3oool0
10000000oooo0?ooo`0000020?ooo`0:0000002HV9P0c<c<0000003oool0000009RHV03oool0c<c<
00000080oooo00@000000?ooo`3oool000000P3oool02@000000oooo0000002HV9P0gMgM0000003^
k^h0oooo000000070?ooo`0?0000003<c<`0V9RH0000003oool0000009RHV03oool0V9RH0000003o
ool08B4Q0>k^kP2HV9P000000080oooo00@000000?ooo`3oool000000P3oool01`000000oooo0000
002HV9P0oooo09RHV00000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0203oool00440oooo00<000000<c<c00@41000P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
000000040?ooo`040000002HV9P0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo
0?ooo`0000020?ooo`040;Zj^P0b<S80V9RH05EEE@D0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000080?ooo`030<c<c014A4@0A4A40080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00@0000009RHV03o
ool000000P3oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0?ooo`3<c<`0410@038b
<P3^k^h50?ooo`0309RHV01EEED0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000D0oooo00<08B4Q07MgM`0Q8B400P3oool00`3<c<`0A4A4
04A4A0060?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool01`000000
oooo0=gMg@0Q8B400000010@402YZJT00P3oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`090000003oool0oooo
0000003oool0000009RHV03oool000000080oooo00<000000?ooo`3oool01@3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool0c<c<0P14A4@20?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`08
0?ooo`00@03oool01P2HV9P0A4A40?ooo`0Q8B40c<c<0?ooo`@000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`000000103oool0102HV9P000000000000000020?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000103oool4000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`05038b<P2j^[X0k^k^010@
403^k^h0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<00000103oool0
0`27QhL0<S8b09RHV0030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000050?ooo`0409RHV0000000000000000080oooo00<000000?oo
o`3oool00`3oool020000000oooo0?ooo`3oool0k^k^024Q8@0b<S80c<c<1P3oool00`1EEED0V9RH
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000050?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`080=gMg@000000oooo010@403MgMd0QhN7038b<P2HV9P70?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000000P3oool01`000000oooo024Q8@27QhL0oooo0=gMg@00
00000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3o
ool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool0V9RH0`0000020?oo
o`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003o
ool0QhN7038b<P2HV9P00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0203oool00400oooo00L0<S8b0:VYZ@3oool0QhN7
06IVIP3oool000000080V9RH00D000000?ooo`3oool000000>k^kP020?ooo`090000003oool0oooo
0000003oool0000009RHV03MgMd0410@00<0oooo00D0V9RH0000003oool0oooo000000070?ooo`@0
00000`3oool00`000000oooo0000000209RHV00:0000003oool0oooo0000003oool0000009RHV03o
ool0^[Zj000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00@000000;Zj^P2HV9P000000P3oool03P000000k^k^0?ooo`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2j^[X000000P3oool02`000000oooo0?ooo`000000
oooo0000002HV9P0gMgM010@403oool000000080V9RH00L000000?ooo`000000V9RH0?ooo`2j^[X0
000000H0oooo00L000000<c<c02HV9P000000?ooo`2YZJT0410@0080oooo00<0A4A408N7Q`3oool0
0`3oool02@000000oooo0?ooo`000000c<c<09RHV0000000oooo0000000209RHV0030000003oool0
oooo0080oooo00@0000009RHV03^k^h08B4Q0P3oool010000000c<c<09RHV00000020?ooo`040000
003oool0oooo00000080c<c<00@000000;Zj^P3<c<`000001`3oool01@2HV9P000000?ooo`3oool0
000000D0oooo00T0410@0>k^kP3oool0k^k^024Q8@2j^[X0k^k^024Q8@3<c<`00`3oool01@1VIVH0
oooo0>k^kP0Q8B40c<c<0080oooo00<000000?ooo`3oool01`0000000`3oool0410@0>k^kP040?oo
o`0309RHV0000000oooo00H0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00L000000<c<c03<c<`000000;Zj^P3<c<`000000080oooo00L000000<c<c03<
c<`000000;Zj^P3<c<`0000000@0oooo00T0MgMg05EEE@3oool0MgMg06IVIP000000V9RH0>k^kP0Q
8B401P3oool01`000000oooo0000002HV9P0oooo09RHV00000000P3oool02P000000c<c<09RHV000
0000oooo0000003<c<`0oooo08N7Q`0000020?ooo`040000003oool0oooo00000080oooo00X00000
0?ooo`3oool000000?ooo`000000V9RH0?ooo`2j^[X000000P3oool01`000000oooo0?ooo`000000
c<c<09RHV00000000`3oool01@2HV9P000000?ooo`3oool0000000L0oooo00l000000;Zj^P2HV9P0
00000?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0>k^kP0Q8B400P3oool010000000
oooo0?ooo`0000020?ooo`070000003oool0000009RHV03oool0V9RH000000020?ooo`040000003<
c<`0V9RH000000@0oooo00<000000?ooo`3oool00P3oool01`000000c<c<0<c<c0000000^[Zj0<c<
c00000000P3oool01`000000c<c<0<c<c0000000^[Zj0<c<c00000001@3oool00`000000oooo0?oo
o`080?ooo`00?`3oool0203MgMd0410@0?ooo`3oool0gMgM010@403oool0V9RH0P0000001P2HV9P0
oooo000000000000V9RH024Q8@D0000000L0oooo09RHV0000000000005EEE@3oool0A4A400800000
00@0V9RH0?ooo`3oool000001`3oool010000000oooo0?ooo`0000020?ooo`80000000D0oooo09RH
V0000000000009RHV0020?ooo`030000003oool0V9RH0080000000<0IVIV0000003oool0103oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool010000000oooo
0?ooo`3oool20000000409RHV0000000V9RH0?ooo`80000000<0V9RH024Q8@2HV9P00`0000000`2H
V9P0oooo09RHV0020000000306IVIP000000oooo0080000000D0oooo000000000000oooo09RHV002
0000000305EEE@3oool0V9RH0080000000<0V9RH0?ooo`2HV9P00P0000000`1VIVH000000?ooo`05
0?ooo`050000001VIVH0000009RHV03oool00P000000101gMgL0^[Zj0000000000030?ooo`<00000
00L0oooo0000002HV9P0000009RHV03oool0V9RH0080000000<0V9RH0?ooo`3oool00P3oool0102H
V9P0000005EEE@0000020?ooo`050000002HV9P0000009RHV03oool00P0000002@3oool000000000
002HV9P0000008N7Q`2HV9P0000009RHV0050?ooo`0504A4A0000000000009RHV03oool00`000004
0?ooo`0307MgM`2HV9P0oooo0080000000@0<S8b0;Zj^P00000000000`3oool5000000030?ooo`3<
c<`0EEEE00X0oooo00<0MgMg09RHV03oool0100000000`2HV9P0oooo0?ooo`050?ooo`040000003o
ool0oooo000000<0oooo00D000000?ooo`3oool0c<c<05EEE@040?ooo`80000000L0V9RH00000027
QhL0V9RH0000002HV9P0oooo0080000000H0V9RH00000027QhL0V9RH0000002HV9P40?ooo`800000
00L0oooo000000000000V9RH0000001EEED0000000H0oooo00<000000?ooo`2HV9P00`0000003P2H
V9P0oooo000000000000V9RH0000002HV9P0oooo0<c<c00@4100000004A4A03^k^h0oooo0P000000
0`3oool0000000000003000000050?ooo`00000000000?ooo`2HV9P00P0000000`1VIVH000000?oo
o`02000000080?ooo`000000000009RHV0000000V9RH0?ooo`14A4@20000000409RHV03oool0oooo
000000H0oooo0P0000001@2HV9P0000009RHV03oool0V9RH00<0000000L0V9RH0?ooo`2HV9P00000
05EEE@000000oooo0080000000<0oooo0000000000000`0000000`3oool0V9RH0000000200000007
09RHV03oool000000000002HV9P0000009RHV0040?ooo`040000003oool0oooo0?ooo`80000000L0
V9RH00000027QhL0V9RH0000002HV9P0oooo0080000000H0V9RH00000027QhL0V9RH0000002HV9P5
0?ooo`030000003oool0oooo00P0oooo000o0?ooo`0305EEE@1gMgL0oooo0080oooo00<0<S8b0:VY
Z@3oool0203oool00`27QhL000000?ooo`0>0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
1@000000k^k^0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`3^k^h00000
0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`0508N7Q`000000oooo0?ooo`0000004P3oool00`000000oooo0?ooo`0G0?ooo`03
08N7Q`000000oooo00@0oooo00<0k^k^05EEE@3oool03`3oool00`1EEED0gMgM0?ooo`090?ooo`05
0>k^kP1EEED0oooo07MgM`1EEED02P3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P00000
0P3oool00`1EEED0gMgM0?ooo`0W0?ooo`030000003oool0oooo01@0oooo00<0QhN70000003oool0
2P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01P0oooo00<0QhN70000003oool0
4P3oool00`000000k^k^0?ooo`0F0?ooo`030>k^kP000000oooo00T0oooo000n0?ooo`0307MgM`00
000000000080oooo0`0000000`2j^[X0oooo0?ooo`070?ooo`04038b<P3oool0oooo038b<P/0oooo
0P0000060?ooo`H000000P3oool00`0b<S80oooo0?ooo`040?ooo`800000103oool2000000D0oooo
0`0000000`3oool0000000000005000000040?ooo`0000000000000001H0oooo0P00000D0?ooo`80
00001@3oool2000000h0oooo00@0<S8b0?ooo`00000000004@3oool2000000D0oooo00<0<S8b0?oo
o`3oool04P3oool00`0b<S80oooo0?ooo`040?ooo`030>k^kP2HV9P0oooo00d0oooo00<0ZJVY0<c<
c03oool02`3oool0103^k^h0V9RH0?ooo`0@410200000003038b<P3oool0oooo00@0oooo00D08B4Q
0000003oool0oooo09RHV0030000000409RHV03oool0ZJVY0<c<c2P0oooo0P00000D0?ooo`04038b
<P3oool0oooo038b<PX0oooo0P0000020?ooo`03038b<P3oool0oooo00X0oooo0P00000H0?ooo`04
038b<P3oool0oooo038b<P80oooo00<0<S8b0?ooo`3oool03P3oool3000001D0oooo0`00000:0?oo
o`00o`3ooooh0?ooo`00o`3ooooh0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 502.062}, {309.938, 0}} -> {-46.324, -0.000837846, \
0.167638, 4.81383*^-6}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(z = 5;\)\ \ \ \ \ \  (*\ 
      Vertical\ position\ \ *) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Plot[
        radFldInt[
          shim, "\<inf\>", "\<ibz\>", {x, \(-1\), z}, {x, 1, 
            z}], {x, \(-30\), 30}, 
        PlotLabel \[Rule] "\<Vertical field integral [Tmm] produced by the \
shim vs horizontal position [mm] , z = 5 mm\>"];\)\[IndentingNewLine]\)}], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.015873 0.502177 27.0162 [
[.02381 -0.0125 -12.125 -14 ]
[.02381 -0.0125 12.125 0 ]
[.18254 -0.0125 -12.125 -14 ]
[.18254 -0.0125 12.125 0 ]
[.34127 -0.0125 -12.125 -14 ]
[.34127 -0.0125 12.125 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.65873 -0.0125 -8 -14 ]
[.65873 -0.0125 8 0 ]
[.81746 -0.0125 -8 -14 ]
[.81746 -0.0125 8 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09693 -39.25 -7 ]
[-0.0125 .09693 0 7 ]
[-0.0125 .23202 -33.25 -7 ]
[-0.0125 .23202 0 7 ]
[-0.0125 .3671 -39.25 -7 ]
[-0.0125 .3671 0 7 ]
[-0.0125 .50218 -10 -7 ]
[-0.0125 .50218 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -220.969 0 ]
[.5 .63053 220.969 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09693 m
.00625 .09693 L
s
gsave
-0.0125 .09693 -100.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.015) show
1.000 setlinewidth
grestore
0 .23202 m
.00625 .23202 L
s
gsave
-0.0125 .23202 -94.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
0 .3671 m
.00625 .3671 L
s
gsave
-0.0125 .3671 -100.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
1.000 setlinewidth
grestore
0 .50218 m
.00625 .50218 L
s
gsave
-0.0125 .50218 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12395 m
.00375 .12395 L
s
0 .15097 m
.00375 .15097 L
s
0 .17798 m
.00375 .17798 L
s
0 .205 m
.00375 .205 L
s
0 .25903 m
.00375 .25903 L
s
0 .28605 m
.00375 .28605 L
s
0 .31306 m
.00375 .31306 L
s
0 .34008 m
.00375 .34008 L
s
0 .39411 m
.00375 .39411 L
s
0 .42113 m
.00375 .42113 L
s
0 .44814 m
.00375 .44814 L
s
0 .47516 m
.00375 .47516 L
s
0 .06992 m
.00375 .06992 L
s
0 .0429 m
.00375 .0429 L
s
0 .01589 m
.00375 .01589 L
s
0 .52919 m
.00375 .52919 L
s
0 .55621 m
.00375 .55621 L
s
0 .58323 m
.00375 .58323 L
s
0 .61024 m
.00375 .61024 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09693 m
1 .09693 L
s
.99375 .23202 m
1 .23202 L
s
.99375 .3671 m
1 .3671 L
s
.99375 .50218 m
1 .50218 L
s
.125 Mabswid
.99625 .12395 m
1 .12395 L
s
.99625 .15097 m
1 .15097 L
s
.99625 .17798 m
1 .17798 L
s
.99625 .205 m
1 .205 L
s
.99625 .25903 m
1 .25903 L
s
.99625 .28605 m
1 .28605 L
s
.99625 .31306 m
1 .31306 L
s
.99625 .34008 m
1 .34008 L
s
.99625 .39411 m
1 .39411 L
s
.99625 .42113 m
1 .42113 L
s
.99625 .44814 m
1 .44814 L
s
.99625 .47516 m
1 .47516 L
s
.99625 .06992 m
1 .06992 L
s
.99625 .0429 m
1 .0429 L
s
.99625 .01589 m
1 .01589 L
s
.99625 .52919 m
1 .52919 L
s
.99625 .55621 m
1 .55621 L
s
.99625 .58323 m
1 .58323 L
s
.99625 .61024 m
1 .61024 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .50218 m
1 .50218 L
s
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -281.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vertical) show
104.438 14.000 moveto
(field) show
129.312 14.000 moveto
(integral) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
168.812 14.000 moveto
(@) show
172.750 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tmm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
198.688 14.000 moveto
(D) show
205.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(produced) show
253.250 14.000 moveto
(by) show
268.250 14.000 moveto
(the) show
285.875 14.000 moveto
(shim) show
312.125 14.000 moveto
(vs) show
325.750 14.000 moveto
(horizontal) show
377.250 14.000 moveto
(position) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
418.812 14.000 moveto
(@) show
422.750 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
441.375 14.000 moveto
(D) show
448.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
454.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
462.625 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
473.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
482.312 14.000 moveto
(mm) show
500.938 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .52646 m
.06244 .53062 L
.10458 .53644 L
.14415 .54356 L
.18221 .55248 L
.22272 .5649 L
.26171 .5801 L
.28158 .58871 L
.29205 .59317 L
.30316 .59754 L
.31304 .60075 L
.31574 .60146 L
.31865 .60212 L
.32117 .60259 L
.3225 .6028 L
.32392 .60298 L
.32531 .60313 L
.32658 .60323 L
.32785 .60329 L
.32905 .60332 L
.33027 .60331 L
.33139 .60327 L
.33262 .60319 L
.33393 .60306 L
.33502 .60291 L
.33618 .60272 L
.33829 .60225 L
.3408 .60149 L
.34309 .6006 L
.34789 .59799 L
.35032 .59625 L
.353 .59397 L
.35773 .58889 L
.36217 .58275 L
.37216 .56313 L
.37778 .54795 L
.38293 .53104 L
.39273 .49038 L
.40185 .44251 L
.42255 .30761 L
.44129 .18353 L
.45116 .12904 L
.4616 .08315 L
.46689 .06473 L
.47271 .04808 L
.47806 .03596 L
.48295 .02739 L
.48796 .02096 L
.49073 .0184 L
.492 .01745 L
Mistroke
.49336 .0166 L
.49463 .01594 L
.49578 .01547 L
.49693 .01511 L
.49802 .01487 L
.49929 .01473 L
.50046 .01472 L
.50174 .01484 L
.50239 .01495 L
.5031 .01512 L
.50441 .01554 L
.50562 .01606 L
.50836 .01771 L
.51077 .0197 L
.51333 .0224 L
.51776 .02848 L
.52265 .03738 L
.52785 .0495 L
.53345 .0658 L
.54357 .1043 L
.55317 .15167 L
.56365 .21431 L
.58477 .35794 L
.59573 .42831 L
.60606 .48458 L
.61534 .52467 L
.62012 .54141 L
.62538 .55688 L
.63015 .56847 L
.63527 .57855 L
.64068 .58686 L
.64573 .59274 L
.65076 .59706 L
.65324 .5987 L
.65553 .59995 L
.65757 .60087 L
.65982 .6017 L
.66207 .60234 L
.66332 .60262 L
.66448 .60283 L
.6657 .60301 L
.66682 .60314 L
.66806 .60324 L
.66874 .60328 L
.66938 .6033 L
.67067 .60332 L
.67186 .6033 L
.67317 .60324 L
.67383 .6032 L
.67455 .60314 L
Mistroke
.67685 .60289 L
.67933 .60251 L
.6838 .60157 L
.68938 .60005 L
.69469 .59831 L
.70465 .59453 L
.74286 .57818 L
.78353 .56276 L
.82268 .5512 L
.86428 .54188 L
.90436 .53507 L
.94293 .52998 L
.97619 .52646 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{521.062, 322.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000890001@R000`400?l00000o`00003oo`3ooooo
0?ooo`/0oooo003o0?ooool0oooo2`3oool00?l0ooooo`3oool;0?ooo`00o`3ooooo0?ooo`/0oooo
003o0?ooool0oooo2`3oool003l0oooo00@0410@0000000@4100MgMg0P3oool01@2HV9P000000000
00000000V9RH03d0oooo100000000`2j^[X0oooo09RHV0030000000309RHV03oool0oooo03h0oooo
0`0000000`3oool0V9RH000000020000000309RHV03oool0oooo03X0oooo00D0V9RH000000000000
000009RHV0120?ooo`<0000000<0oooo09RHV00000000P0000000`2HV9P0oooo0?ooo`0l0?ooo`@0
000000<0^[Zj0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0k0?ooo`04010@40000000410@07Mg
M`80oooo00D0V9RH000000000000000009RHV00A0?ooo`00@P3oool0201gMgL0IVIV0?ooo`000000
V9RH0?ooo`2HV9P00000?@3oool02`3<c<`0k^k^0?ooo`3<c<`0EEEE0?ooo`000000V9RH0?ooo`2H
V9P000000440oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000003`0oooo00D0000009RH
V03oool0V9RH000000130?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000n0?ooo`0;
0<c<c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo09RHV0000000@03oool0201gMgL0IVIV
0?ooo`000000V9RH0?ooo`2HV9P000004@3oool004<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0l0?ooo`030<c<c03^k^h0oooo0080oooo00D000000?ooo`3oool0oooo00000011
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?oo
o`3oool0000004<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0m0?ooo`03
0<c<c03^k^h0oooo0080oooo00D000000?ooo`3oool0oooo000000110?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool03`3oool003P0oooo1`0000020?ooo`050=gMg@27QhL000000?oo
o`0000000`3oool00`000000oooo0?ooo`0d0?ooo`L000000P3oool01@2YZJT0k^k^0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0=03oool7000000@0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?ooo`000000@`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo03h0oooo00D0ZJVY0>k^kP3oool0oooo000000030?oo
o`030000003oool0oooo03d0oooo00D0gMgM08N7Q`000000oooo000000030?ooo`030000003oool0
oooo00l0oooo00100?ooo`0605EEE@0@4100000009RHV03oool000000`3oool00`000000oooo0?oo
o`0m0?ooo`050=gMg@1VIVH0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0o0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool00000
04<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0n0?ooo`050=gMg@1VIVH0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0l0?ooo`0605EEE@0@4100000009RHV03oool0
00000`3oool00`000000oooo0?ooo`0?0?ooo`00@P3oool0102j^[X0V9RH0?ooo`0000030?ooo`03
0000003oool0oooo03/0oooo00@0MgMg0?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
00000440oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0j0?ooo`050000003o
ool0oooo0?ooo`000000@`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo03`0
oooo00@0MgMg0?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000400oooo00@0^[Zj
09RHV03oool000000`3oool00`000000oooo0?ooo`0?0?ooo`00?`3oool02`14A4@0^[Zj0?ooo`2j
^[X000000?ooo`000000V9RH0?ooo`2HV9P0000003d0oooo00@0000009RHV02HV9P000000P3oool0
1@000000V9RH0?ooo`2HV9P000000440oooo00P000000?ooo`3oool0000009RHV03oool0V9RH0000
03`0oooo00D0000009RHV03oool0V9RH000000130?ooo`080000003oool0oooo0000002HV9P0oooo
09RHV000000n0?ooo`040000002HV9P0V9RH00000080oooo00D0000009RHV03oool0V9RH0000000m
0?ooo`0;04A4A02j^[X0oooo0;Zj^P000000oooo0000002HV9P0oooo09RHV00000004@3oool003l0
oooo00L0k^k^04A4A0000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool0>`3oool0
102HV9P000000000002HV9P20?ooo`0509RHV000000000000000002HV9P0@03oool01@0Q8B400000
0?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool0>P3oool01@2HV9P00000000000000000V9RH
0480oooo00D08B4Q0000003oool0oooo09RHV0030000000309RHV03oool0oooo03`0oooo00@0V9RH
000000000000V9RH0P3oool01@2HV9P00000000000000000V9RH03d0oooo00L0k^k^04A4A0000000
000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool03`3oool00?l0ooooo`3oool;0?ooo`00
o`3ooooo0?ooo`/0oooo003o0?ooool0oooo2`3oool00?l0ooooo`3oool;0?ooo`00o`3ooooo0?oo
o`/0oooo003o0?ooool0oooo2`3oool00?l0ooooo`3oool;0?ooo`00=P3ooooo00000<X000002P3o
ool003H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo000f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0h@3oool00`000000oooo
0?ooo`3Q0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0>40oooo00<0
00000?ooo`3oool0h@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3Q
0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0203oool003H0oooo0`00003N0?oo
o`L00000gP3oool3000000X0oooo000f0?ooo`030000003oool0oooo0=d0oooo0P0000020?ooo`05
0000003oool0oooo0?ooo`000000g`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000
oooo0?ooo`3L0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=`0
oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0f`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0f`3oool00`000000oooo
0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo00P0oooo000f
0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
203oool003H0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`080?ooo`00=P3oool0
0`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3G0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo
0=L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0=L0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0eP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0eP3oool00`000000
oooo0?ooo`080?ooo`00=P3oool300000=H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0=@0oooo0`00000:0?ooo`00=P3oool00`000000oooo0?oo
o`3F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`080?oo
o`00=P3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d`3o
ool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo00P0oooo000f0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0203oool003H0
oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0=80oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=80oooo00<0
00000?ooo`3oool0203oool003H0oooo0`00003A0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`3@0?ooo`<000002P3oool003H0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
203oool003H0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`080?ooo`00=P3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo
0<l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0c`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00P0oooo
000f0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0203oool001<0oooo00D0V9RH
000000000000000009RHV0020?ooo`03038b<P3oool0V9RH00<0000000@0V9RH0?ooo`3oool0oooo
0`0000000`3oool0410@000000020000000309RHV03oool0oooo00L0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
c`3oool00`000000oooo0?ooo`080?ooo`004`3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo
00D0000009RHV03oool0V9RH000000040?ooo`030000003oool0oooo00<0oooo00<0V9RH0000003o
ool0203oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00P0oooo000C0?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`@00000c@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0b`3oool4000000X0oooo000<0?ooo`P0
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`080?ooo`004`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<0V9RH0000003oool0203oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo000C0?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01000
00000`2HV9P0oooo0?ooo`070?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0203o
ool001<0oooo00D0000009RHV03oool0V9RH000000040?ooo`050000002HV9P0oooo09RHV0000000
103oool01@000000oooo0?ooo`1gMgL0EEEE00`0oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`080?ooo`004`3oool01@2HV9P00000000000000000V9RH00@0oooo00D0V9RH00000000
0000000009RHV0030?ooo`03024Q8@000000oooo0080oooo00@0410@000000000000<S8b2@3oool0
0`000000oooo0?ooo`3=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo
0<d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0<d0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00P0oooo
000f0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0203oool003H0oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3o
ool0203oool003H0oooo0`00003;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`390?ooo`<000002P3oool003H0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00P0oooo000f0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0203oool003H0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<X0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0<X0oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`08
0?ooo`00=P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00P0oooo000f0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00P0oooo000f0?ooo`<00000b@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0a`3oool3000000X0oooo000f0?ooo`030000003oool0oooo
0<T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0<T0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00P0oooo
000f0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0203oool003H0oooo00<00000
0?ooo`3oool0b03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0b03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3o
ool0203oool003H0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`080?ooo`00=P3o
ool00`000000oooo0?ooo`370?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`080?ooo`00=P3oool300000<L0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0<D0oooo0`00000:0?ooo`00=P3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`370?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<H0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0<L0oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`08
0?ooo`00=P3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00P0oooo000f0?ooo`03
0000003oool0oooo0<H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0<H0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
aP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
aP3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0203oool0
03H0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000
oooo0?ooo`350?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`350?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0<D0oooo
00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`080?ooo`00=P3oool300000<D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0<<0oooo0`00000:0?ooo`00=P3oool00`000000oooo0?ooo`340?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3o
ool0203oool003H0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`080?ooo`00=P3o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00P0
oooo000f0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0203oool003H0oooo00<0
00000?ooo`3oool0``3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0``3oool00`000000oooo0?ooo`080?ooo`006@3oool01@2HV9P0000000000000
0000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`3oool3000000T0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`080?ooo`006@3oool01@000000V9RH0?oo
o`2HV9P0000000@0oooo00D0000009RHV03oool0V9RH000000040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`080?ooo`006@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00P0oooo100000320?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`300?ooo`@000002P3oool00180oooo200000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`080?ooo`006@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`080?ooo`006@3oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`080?ooo`006@3oool01@000000V9RH0?ooo`2H
V9P0000000@0oooo00D0000009RHV03oool0V9RH000000040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`080?ooo`006@3oool01@2HV9P000000000
00000000V9RH00@0oooo00D0V9RH000000000000000009RHV0030?ooo`03024Q8@000000oooo00T0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo
0?ooo`320?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`320?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<80oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0<80oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`08
0?ooo`00=P3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo00P0oooo000f0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`080?ooo`00=P3oool300000<40oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;l0oooo0`00000:0?ooo`00=P3oool0
0`000000oooo0?ooo`310?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`310?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0`@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0`@3oool00`000000
oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00P0oooo
000f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0203oool003H0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3o
ool0203oool003H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`080?ooo`00=P3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`080?ooo`00=P3oool300000;l0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0;d0oooo0`00000:0?ooo`00=P3oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`08
0?ooo`00=P3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00P0oooo000f0?ooo`03
0000003oool0oooo0;l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0203oool0
03H0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool0203oool003H0oooo0`00002n0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`2k0?ooo`<000002P3oool003H0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool0203oool003H0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`080?ooo`00=P3o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo0;d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0;`0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0_03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0_03oool00`00
0000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0203oool003H0oooo00<0
00000?ooo`3oool0_03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0_03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2k
0?ooo`030000003oool0oooo00P0oooo000f0?ooo`<00000_03oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0^@3oool3000000X0oooo000f0?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0203oool0
03H0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`080?ooo`00=P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo00P0oooo000C0?oo
o`0509RHV000000000000000002HV9P00P3oool00`0b<S80oooo09RHV0030000000309RHV03oool0
V9RH00<0000000<0V9RH0?ooo`0@41000`0000000`2HV9P0oooo0?ooo`070?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0203oool001<0oooo00D0000009RHV03oool0V9RH00000004
0?ooo`0;0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RHV0000000103oool00`2H
V9P000000?ooo`080?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0203oool001<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool400000;T0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;H0oooo1000
000:0?ooo`00303oool8000000<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`080?ooo`004`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`2HV9P000000?ooo`080?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool0203oool001<0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0000000<0000000<0V9RH0?ooo`3oool01`3o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo00P0oooo000C0?ooo`050000002HV9P0
oooo09RHV0000000103oool03P000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0
00000?ooo`1gMgL0EEEE303oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo00P0oooo
000C0?ooo`0509RHV000000000000000002HV9P0103oool01`2HV9P00000000000000000V9RH0?oo
o`2HV9P00`000000102HV9P0oooo0?ooo`0@410200000003038b<P3oool0oooo00L0oooo00<00000
0?ooo`3oool0^@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0^@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool0203oool003H0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`080?ooo`00=P3o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo0;P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0;P0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`<00000^03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0]@3oool3000000X0oooo000f0?ooo`030000003oool0oooo0;L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0;L0oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`08
0?ooo`00=P3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo00P0oooo000f0?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2f0?ooo`030000003o
ool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0203oool0
03H0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000
oooo0?ooo`2f0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`2f0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;H0oooo
00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?oo
o`080?ooo`00=P3oool300000;H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0;@0oooo0`00000:0?ooo`00=P3oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool0203oool003H0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`080?ooo`00=P3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0203oool003H0oooo00<0
00000?ooo`3oool0]03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0]03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;@0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;@0oooo00<000000?oo
o`3oool0203oool003H0oooo0`00002d0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`2b0?ooo`<000002P3oool003H0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0203oool0
03H0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`080?ooo`00=P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00P0oooo000f0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0203o
ool003H0oooo0`00002a0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`2`0?ooo`<000002P3oool003H0oooo00<000000?ooo`3oool0/@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0203oool003H0oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool0203oool003H0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`080?ooo`00
=P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool0203oool002P0oooo00D0V9RH000000000000000009RH
V0090?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0203oool002P0oooo00D00000
09RHV03oool0V9RH000000090?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0203o
ool002P0oooo00D000000?ooo`3oool0oooo000000090?ooool00000bP00000:0?ooo`00:03oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?oo
o`080?ooo`00:03oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0[`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`080?ooo`00:03oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`080?ooo`00:03oool01@000000V9RH0?ooo`2H
V9P0000000T0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`080?ooo`00:03oool0
1@2HV9P00000000000000000V9RH00T0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`080?ooo`00=P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00P0oooo000f0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2/0?ooo`030000
003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0203o
ool003H0oooo00<000000?ooo`3oool0203oool6000009l0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo09d0oooo1@00000:0?ooo`030000003oool0
oooo00P0oooo000f0?ooo`<000003P3oool9000009D0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo09H0oooo1`00000=0?ooo`<000002P3oool003H0
oooo00<000000?ooo`3oool05`3oool7000008h0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo08d0oooo2000000F0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`030000003oool0oooo01h0oooo1`0000270?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`240?ooo`T000007P3oool00`000000oooo
0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`0U0?ooo`H00000P03oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0O03oool8000002L0oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0:`3oool6000007X0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07H0oooo1P00000_
0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo0340oooo1P00001d0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1_0?oo
o`H00000=@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`0g0?ooo`H0
0000K@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0JP3oool5000003/0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0
?@3oool5000006P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo06D0oooo1@0000100?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003o
ool0oooo0480oooo1000001T0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`1P0?ooo`D00000A@3oool00`000000oooo0?ooo`080?ooo`00=P3oool0
0`000000oooo0?ooo`160?ooo`D00000GP3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0FP3oool5000004X0oooo00<000000?ooo`3oool0203oool0
03H0oooo00<000000?ooo`3oool0B`3oool4000005X0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo05L0oooo0`00001?0?ooo`030000003oool0oooo
00P0oooo000f0?ooo`030000003oool0oooo04l0oooo1000001F0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1D0?ooo`<00000DP3oool00`000000
oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`1C0?ooo`<00000DP3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0D03oool3000005D0oooo
00<000000?ooo`3oool0203oool003H0oooo0`00001F0?ooo`<00000C`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0C@3oool3000005H0oooo0`00
000:0?ooo`00=P3oool00`000000oooo0?ooo`1I0?ooo`<00000C03oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0BP3oool3000005/0oooo00<00000
0?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0G03oool3000004P0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04H0oooo0`00001N0?oo
o`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo05l0oooo0`0000150?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`130?ooo`<0
0000H@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`1R0?ooo`<00000
@P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
@03oool3000006@0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0I@3o
ool3000003h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo03d0oooo0P00001W0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0
oooo06P0oooo0P00000l0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0j0?ooo`<00000J@3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`00
0000oooo0?ooo`1Z0?ooo`<00000>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0=P3oool3000006`0oooo00<000000?ooo`3oool0203oool003H0
oooo00<000000?ooo`3oool0K@3oool2000003D0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo03<0oooo0P00001_0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`030000003oool0oooo06l0oooo0P00000c0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0`0?ooo`<00000L@3oool00`000000oooo
0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`1a0?ooo`<00000;`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0;@3oool2000007@0oooo00<0
00000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0M03oool3000002`0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02X0oooo0`00001f
0?ooo`030000003oool0oooo00P0oooo000f0?ooo`<00000M`3oool3000002P0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02L0oooo0P00001g0?oo
o`<000002P3oool003H0oooo00<000000?ooo`3oool0NP3oool3000002D0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02@0oooo0`00001k0?ooo`03
0000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo07d0oooo0P00000R0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0P0?ooo`<00000
OP3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?ooo`1o0?ooo`<000007P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3o
ool200000840oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0PP3oool2
000001/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`8000006P3oool3
000008<0oooo00<000000?ooo`3oool0203oool003H0oooo00<000000?ooo`3oool0Q03oool30000
01L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
01D0oooo0P0000260?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo08L0
oooo0P00000D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0B0?ooo`800000R03oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo
0?ooo`290?ooo`<000003`3oool2000004@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0?0?ooo`800000RP3oool00`000000oooo0?ooo`080?ooo`00=P3oool00`000000oooo0?oo
o`2<0?ooo`8000002P3oool3000004H0oooo00<000000?ooo`3oool0A03oool3000000T0oooo1@00
002<0?ooo`030000003oool0oooo00P0oooo000f0?ooo`030000003oool0oooo08h0oooo2P000019
0?ooo`030000003oool0oooo04L0oooo2@00002A0?ooo`030000003oool0oooo00P0oooo000f0?oo
o`030000003oool0oooo0>40oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`080?oo
o`00=P3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3o
ool0203oool003H0oooo0`00003Q0?ooo`030000003oool0oooo0=l0oooo0`00000:0?ooo`00=P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool003H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo000f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`00=P3ooooo00000<X000002P3oool00?l0ooooo`3oool;0?ooo`00o`3o
oooo0?ooo`/0oooo003o0?ooool0oooo2`3oool00?l0ooooo`3oool;0?ooo`00o`3ooooo0?ooo`/0
oooo003o0?ooool0oooo2`3oool00980oooo00H0V9RH010@40000000410@07MgM`3^k^hf0?ooo`<0
0000<P3oool00`0@410000000<c<c01c0?ooo`<00000S@3oool00980oooo00H000000;Zj^P3oool0
k^k^08N7Q`0b<S8A0?ooo`<00000703oool3000000@0oooo00<000000?ooo`3oool0<P3oool00`3^
k^h08B4Q0?ooo`1c0?ooo`030000003oool0oooo02H0oooo0`00000D0?ooo`<000000`3oool00`3<
c<`0oooo0?ooo`160?ooo`00TP3oool01P1gMgL0k^k^0?ooo`3oool0gMgM00000140oooo00<00000
0>k^kP3oool07@3oool00`3^k^h000000?ooo`030?ooo`030000003oool0oooo03<0oooo00<0IVIV
09RHV03oool0LP3oool00`000000oooo0?ooo`0V0?ooo`030000003^k^h0oooo01D0oooo00<0k^k^
0000003oool00P3oool00`0@4100oooo0?ooo`160?ooo`00@P3oool00`3MgMd000000<c<c0020?oo
o`0509RHV0000000410@0<c<c03oool00`0000020?ooo`030:VYZ@0b<S8000000080000000X0V9RH
0000000@4100c<c<0?ooo`2HV9P0000009RHV00Q8B40EEEE0`0000050?ooo`<0000000T0oooo0000
00000000000009RHV0000000410@0<c<c03oool00`000000102HV9P000000000001gMgL2000000@0
oooo1P000000303oool000000000003oool0ZJVY038b<P2HV9P00000010@403<c<`0oooo07MgM`<0
000000<0410@08N7Q`0000000P0000001P3oool0V9RH0000002HV9P08B4Q05EEE@<000001@3oool0
0`000000oooo0?ooo`030?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`D0000000@0
oooo000000000000oooo0P0000040?ooo`030000003oool0oooo0080oooo00D0000004A4A0000000
V9RH0?ooo`03000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`2HV9P00P0000001`1gMgL0
00000000003oool0V9RH0000002HV9P00P0000002`2HV9P00000010@403<c<`0oooo09RHV0000000
410@0<c<c03oool0V9RH0080000000<0MgMg000000000000103oool0100b<S8000000000002HV9P3
0?ooo`0309RHV00Q8B40oooo00D0oooo00<0ZJVY038b<P0000000P0000001`3oool000000000002H
V9P00000010@403<c<`01@3oool01@000000EEEE0000002HV9P0oooo00<0000000<0oooo00000000
00001P000000103oool000000000003oool2000000@0oooo00P0gMgM0000003MgMd0oooo0000001E
EED0000009RHV0D0oooo0`000000103oool000000000002HV9P30000000309RHV03oool000000080
000000<0oooo0000000000001P0000001P2HV9P00000000000000000V9RH0?ooo`<0000000/0oooo
000000000000oooo0:VYZ@0b<S80V9RH0000002HV9P08B4Q05EEE@03000000D0oooo00H0000004A4
A0000000V9RH0?ooo`2HV9P30000000709RHV03oool0000005EEE@000000V9RH0?ooo`0300000003
0?ooo`2YZJT0<S8b00<0000000H0V9RH000000000000000009RHV03oool3000000030?ooo`000000
000000@0oooo00@000000?ooo`3oool0oooo0`000000103oool000000000003oool5000000040?oo
o`00000000000?ooo`8000000`3oool01@000000oooo0?ooo`3oool0410@00D0oooo1@00000>0?oo
o`05010@4000000000000000002HV9P0103oool3000000040?ooo`00000000000?ooo`D0000000@0
oooo000000000000oooo0P00000E0?ooo`00@P3oool00`1VIVH0410@06IVIP020?ooo`040000002H
V9P0^[Zj010@4080oooo00D000000?ooo`3oool0oooo000000020?ooo`0>0000003oool0000009RH
V02j^[X0<S8b0?ooo`000000V9RH0=gMg@000000k^k^0?ooo`0000070?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000002HV9P0^[Zj010@4080oooo00L000000?ooo`000000V9RH0?ooo`3<c<`0
000000H0oooo00@000000?ooo`3oool000000P3oool030000000oooo0?ooo`000000oooo0000002H
V9P0^[Zj010@403oool0<S8b0=gMg@D0oooo00X000000?ooo`3oool0000009RHV03MgMd000000>k^
kP3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool00P3oool010000000c<c<09RHV00000020?ooo`0>0000003oool0oooo
0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo0<c<c00000020?ooo`0D0000002HV9P0
c<c<0000003oool0000009RHV02j^[X0<S8b0?ooo`000000V9RH0;Zj^P0@4100oooo0000002HV9P0
oooo0<c<c00000050?ooo`040000003^k^h0V9RH000000<0oooo00<0<S8b0000003<c<`01@3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0000009RHV02j^[X0410@1@3oool0100Q8B40
k^k^09RHV00000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000050?ooo`0808N7Q`000000QhN70?ooo`0Q8B40k^k^09RHV0000006
0?ooo`0:0000003oool0oooo0000003oool0000009RHV03oool0V9RH00000080oooo00P000000?oo
o`3oool0oooo0000003oool0c<c<024Q8@80oooo00H0<S8b0000002HV9P0oooo09RHV00000020?oo
o`040000003oool0oooo00000080oooo00T000000?ooo`000000V9RH0=gMg@000000k^k^0?ooo`00
00001P3oool03`000000c<c<09RHV0000000oooo0000002HV9P0oooo09RHV0000000oooo024Q8@3^
k^h0V9RH000000020?ooo`040000003oool0oooo00000080oooo00L000000?ooo`000000V9RH0?oo
o`2HV9P000000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00L0oooo00D0c<c<024Q8@3oool0oooo038b<P050?ooo`L00000
1@3oool00`2HV9P000000?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000F0?ooo`00@P3oool00`000000c<c<010@40020?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
000000@0oooo00@0000009RHV03oool000000P3oool00`000000oooo0?ooo`050?ooo`070000003o
ool0oooo0?ooo`000000oooo000000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000103o
ool01@3MgMd08B4Q0000000@4100ZJVY0080oooo00L000000?ooo`3oool0000009RHV03oool00000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00@000000?ooo`3oool000000P3oool0102j^[X0<S8b09RHV01EEED50?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000002@3oool00`3<c<`0A4A404A4A0020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000050?ooo`03024Q8@1gMgL08B4Q0080oooo00<0c<c<04A4A014A4@01P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`2H
V9P0EEEE0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00H000000?ooo`000000V9RH0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo0<c<c080A4A40P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0203oool00`2HV9P0EEEE0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001H0oooo0011
0?ooo`0609RHV014A4@0oooo024Q8@3<c<`0oooo100000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo000000040?ooo`0409RHV0000000000000000080oooo00<000000?oo
o`3oool01@3oool01P000000oooo0?ooo`3oool000000?ooo`@000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0?ooo`000000oooo00@0000000H0oooo024Q8@27QhL0oooo0=gMg@0000020?ooo`040000003oool0
oooo09RHV0<000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`000000103oool4000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`05038b<P2j^[X0k^k^010@
403^k^h0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<000001@3oool0
0`27QhL0<S8b09RHV0030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`080=gMg@000000oooo010@403MgMd0QhN7038b<P2H
V9P70?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000030?oo
o`080000003oool0oooo0?ooo`1EEED0V9RH0?ooo`0000030?ooo`040000003oool0oooo00000080
oooo00H000000?ooo`3oool000000?ooo`2HV9P300000080oooo00<000000?ooo`3oool0103oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`27QhL0<S8b09RHV0030?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`090?ooo`0305EEE@2HV9P0oooo0180oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000005P3o
ool00440oooo00L0<S8b0:VYZ@3oool0QhN706IVIP3oool000000080V9RH00D000000?ooo`3oool0
00000>k^kP020?ooo`090000003oool0oooo0000003oool0000009RHV03MgMd0410@00<0oooo00D0
V9RH0000003oool0oooo000000070?ooo`070000003oool0oooo0?ooo`000000oooo0000000209RH
V00:0000003oool0oooo0000003oool0000009RHV03oool0^[Zj000000H0oooo00L000000?ooo`3o
ool000000<c<c02HV9P000000080oooo00<000000?ooo`0000000P2HV9P01`000000oooo0000003<
c<`0oooo08N7Q`0000000P3oool00`000000k^k^0?ooo`020?ooo`0509RHV0000000oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00L000000<c<c03<
c<`000000;Zj^P3<c<`000000080oooo00L000000<c<c03<c<`000000;Zj^P3<c<`0000000D0oooo
00<000000?ooo`3oool00P3oool010000000^[Zj09RHV00000020?ooo`0>0000003^k^h0oooo0000
002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo0;Zj^P0000020?ooo`0;0000003oool0oooo
0000003oool0000009RHV03MgMd0410@0?ooo`0000000P2HV9P01`000000oooo0000002HV9P0oooo
0;Zj^P0000001@3oool01`000000c<c<09RHV0000000oooo0:VYZ@0@41000P3oool00`14A4@0QhN7
0?ooo`030?ooo`090000003oool0oooo0000003<c<`0V9RH0000003oool000000080V9RH00<00000
0?ooo`3oool00`3oool010000000V9RH0>k^kP0Q8B420?ooo`040000003<c<`0V9RH00000080oooo
00@000000?ooo`3oool000000P3<c<`010000000^[Zj0<c<c00000040?ooo`0907MgM`1EEED0oooo
07MgM`1VIVH0000009RHV03^k^h08B4Q00H0oooo00X000000<c<c02HV9P000000?ooo`000000V9RH
0?ooo`2HV9P000000P3oool040000000k^k^0?ooo`3oool000000?ooo`1VIVH0oooo0>k^kP0Q8B40
c<c<0000002HV9P0oooo09RHV00000020?ooo`040000003<c<`0V9RH00000080oooo00H000000?oo
o`3oool0oooo09RHV00000020?ooo`030000003oool0oooo00@0oooo00l000000;Zj^P2HV9P00000
0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0>k^kP0Q8B400P3oool010000000oooo
0?ooo`0000020?ooo`070000003oool0000009RHV03oool0V9RH000000020?ooo`040000003<c<`0
V9RH000000D0oooo00<000000?ooo`3oool00P3oool01`000000c<c<0<c<c0000000^[Zj0<c<c000
00000P3oool01`000000c<c<0<c<c0000000^[Zj0<c<c0000000103oool00`000000oooo0?ooo`07
0?ooo`0506IVIP3oool0k^k^024Q8@3<c<`01@3oool7000000D0oooo00<0V9RH0000003oool0103o
ool01`000000c<c<0<c<c0000000^[Zj0<c<c00000000P3oool01`000000c<c<0<c<c0000000^[Zj
0<c<c00000005P3oool00400oooo00P0gMgM010@403oool0oooo0=gMg@0@4100oooo09RHV0800000
00H0V9RH0?ooo`000000000009RHV00Q8B45000000070?ooo`2HV9P000000000001EEED0oooo04A4
A0020000000409RHV03oool0oooo000000H0oooo0`0000001@0b<S8000000000003oool0V9RH0080
000000H0V9RH0?ooo`3oool000000?ooo`2HV9P20000000306IVIP000000oooo00@0oooo0P000000
1`3oool000000000002HV9P0000009RHV03oool00`0000002`2HV9P000000000002HV9P0oooo0<c<
c00@4100000004A4A03^k^h0oooo0080000000<0V9RH024Q8@14A4@00P000000102HV9P0oooo0?oo
o`0000060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0300000007
09RHV0000000QhN709RHV0000000V9RH0?ooo`020000000609RHV0000000QhN709RHV0000000V9RH
1@3oool010000000oooo0?ooo`3oool20000000409RHV0000000V9RH0?ooo`80000000<0V9RH024Q
8@2HV9P00`0000000`2HV9P0oooo09RHV0020000000306IVIP000000oooo0080000000D0oooo0000
00000000oooo09RHV0020000000305EEE@3oool0V9RH0080000000<0V9RH0?ooo`2HV9P00P000000
0`1VIVH000000?ooo`040?ooo`050000001VIVH0000009RHV03oool00P000000101gMgL0^[Zj0000
000000030?ooo`<0000000L0oooo0000002HV9P0000009RHV03oool0V9RH0080000000<0V9RH0?oo
o`3oool00`3oool0102HV9P0000005EEE@0000020?ooo`050000002HV9P0000009RHV03oool00P00
00002@3oool000000000002HV9P0000008N7Q`2HV9P0000009RHV0040?ooo`80000000L0oooo0000
00000000V9RH0000001EEED0000000H0oooo00H0000009RHV0000000V9RH0?ooo`2HV9P300000006
09RHV03oool000000000002HV9P08B4Q0P0000000`3oool00000000000030000000609RHV0000000
00000000002HV9P0oooo0P000000102HV9P0000009RHV03oool30000000404A4A0000000000009RH
V080oooo00<000000?ooo`3oool00`3oool20000000509RHV0000000V9RH0?ooo`2HV9P00`000000
1`2HV9P0oooo09RHV0000000EEEE0000003oool00P0000000`3oool0000000000003000000030?oo
o`2HV9P000000080000000L0V9RH0?ooo`000000000009RHV0000000V9RH00D0oooo00@000000?oo
o`3oool0oooo0P0000001`2HV9P0000008N7Q`2HV9P0000009RHV03oool00P0000001P2HV9P00000
08N7Q`2HV9P0000009RHV0@0oooo00<000000?ooo`3oool01`3oool5000000h0oooo100000000`2H
V9P0oooo0?ooo`020?ooo`80000000L0V9RH00000027QhL0V9RH0000002HV9P0oooo0080000000H0
V9RH00000027QhL0V9RH0000002HV9PF0?ooo`00@03oool00`1EEED0MgMg0?ooo`020?ooo`03038b
<P2YZJT0oooo00P0oooo00<0QhN70000003oool03P3oool00`000000oooo0?ooo`050?ooo`030000
003^k^h0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`0308N7
Q`000000oooo01D0oooo00<000000?ooo`3oool0103oool01@000000k^k^0?ooo`3oool000000080
oooo00@000000?ooo`3oool000005@3oool00`3^k^h000000?ooo`0F0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`0508N7Q`000000oooo
0?ooo`0000004`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0QhN7
0000003oool01P3oool00`000000oooo0?ooo`0G0?ooo`0308N7Q`000000oooo01<0oooo00<00000
0>k^kP3oool05@3oool00`3^k^h000000?ooo`0K0?ooo`0307MgM`1EEED0oooo02d0oooo000o0?oo
o`0307MgM`00000000000080oooo0`0000000`2j^[X0oooo0?ooo`070?ooo`04038b<P3oool0oooo
038b<P/0oooo0P0000070?ooo`0509RHV0000000410@0?ooo`0b<S801P3oool2000000@0oooo0P00
00060?ooo`03038b<P3oool0oooo00H0oooo00<0<S8b0?ooo`3oool04`3oool2000000H0oooo0`00
00000`3oool0000000000005000001@0oooo0`00000F0?ooo`800000503oool2000000@0oooo0P00
000>0?ooo`04038b<P3oool0000000000180oooo0P0000050?ooo`03038b<P3oool0oooo01T0oooo
0P00000?0?ooo`03038b<P3oool0oooo0140oooo00<0<S8b0?ooo`3oool0103oool2000001L0oooo
00@0<S8b0?ooo`3oool0<S8b0P3oool00`0b<S80oooo0?ooo`0?0?ooo`<00000503oool3000001d0
oooo00@0410@000000000000<S8b:`3oool00?l0ooooo`3oool;0?ooo`00o`3ooooo0?ooo`/0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 520.062}, {321.062, 0}} -> {-39.0432, -0.0201878, \
0.138234, 8.12178*^-5}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 1004}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{837, 851},
WindowMargins->{{62, Automatic}, {56, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowCellLabel->False,
Magnification->1,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`_mooh/=<`Tk0fL5N`?P0080004/0B`000000]P2:001
0000I00000400`<30?l00BL?00400@P3lM0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 67, 0, 62, "Title"],
Cell[1787, 51, 341, 9, 82, "Text"],

Cell[CellGroupData[{
Cell[2153, 64, 43, 0, 59, "Section"],
Cell[2199, 66, 1906, 28, 254, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4142, 99, 43, 0, 39, "Section"],
Cell[4188, 101, 444, 9, 110, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4669, 115, 33, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[4727, 119, 569, 9, 127, "Input"],
Cell[5299, 130, 220, 4, 22, "Print"],
Cell[5522, 136, 121, 2, 37, "Print"]
}, Open  ]],
Cell[5658, 141, 2317, 41, 575, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8012, 187, 38, 0, 39, "Section"],
Cell[8053, 189, 280, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[8358, 198, 2238, 39, 447, "Input"],
Cell[10599, 239, 91, 1, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10739, 246, 40, 0, 39, "Section"],
Cell[10782, 248, 56, 1, 47, "Input"],
Cell[10841, 251, 263, 5, 95, "Input"],

Cell[CellGroupData[{
Cell[11129, 260, 70, 1, 47, "Input"],
Cell[11202, 263, 69950, 2319, 296, 33170, 1860, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[81201, 2588, 55, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[81281, 2592, 505, 8, 143, "Input"],
Cell[81789, 2602, 86129, 2028, 319, 20878, 1218, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167955, 4635, 420, 9, 127, "Input"],
Cell[168378, 4646, 81895, 1834, 331, 17406, 1033, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

